# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_bs_controller.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ydb/core/protos/counters_bs_controller.proto\x12\x1eNKikimr.NBlobStorageController\x1a\x1eydb/core/protos/counters.proto*\xae\x0b\n\x0f\x45SimpleCounters\x12:\n\x1a\x43OUNTER_RESPONSE_TIME_USEC\x10\x00\x1a\x1a\x82\xd6\x1b\x16\n\x14ResponseTimeMicrosec\x12Q\n)COUNTER_GROUPS_WITH_SLOTS_ON_FAULTY_DISKS\x10\x01\x1a\"\x82\xd6\x1b\x1e\n\x1cGroupsWithSlotsOnFaultyDisks\x12;\n\x1d\x43OUNTER_SLOTS_ON_FAULTY_DISKS\x10\x02\x1a\x18\x82\xd6\x1b\x14\n\x12SlotsOnFaultyDisks\x12;\n\x1d\x43OUNTER_BYTES_ON_FAULTY_DISKS\x10\x03\x1a\x18\x82\xd6\x1b\x14\n\x12\x42ytesOnFaultyDisks\x12T\n*COUNTER_PDISKS_WITHOUT_EXPECTED_SLOT_COUNT\x10\x04\x1a$\x82\xd6\x1b \n\x1ePDisksWithoutExpectedSlotCount\x12\x37\n\x1b\x43OUNTER_TO_BE_REMOVED_DISKS\x10\x05\x1a\x16\x82\xd6\x1b\x12\n\x10ToBeRemovedDisks\x12]\n0COUNTER_GROUPS_WITH_SLOTS_ON_TO_BE_REMOVED_DISKS\x10\x06\x1a\'\x82\xd6\x1b#\n!GroupsWithSlotsOnToBeRemovedDisks\x12G\n$COUNTER_SLOTS_ON_TO_BE_REMOVED_DISKS\x10\x07\x1a\x1d\x82\xd6\x1b\x19\n\x17SlotsOnToBeRemovedDisks\x12G\n$COUNTER_BYTES_ON_TO_BE_REMOVED_DISKS\x10\x08\x1a\x1d\x82\xd6\x1b\x19\n\x17\x42ytesOnToBeRemovedDisks\x12M\n&COUNTER_PDISKS_WITHOUT_EXPECTED_SERIAL\x10\t\x1a!\x82\xd6\x1b\x1d\n\x1bPDisksWithoutExpectedSerial\x12;\n\x1d\x43OUNTER_DRIVE_SERIAL_NOT_SEEN\x10\n\x1a\x18\x82\xd6\x1b\x14\n\x12\x44riveSerialNotSeen\x12:\n\x1c\x43OUNTER_DRIVE_SERIAL_REMOVED\x10\x0b\x1a\x18\x82\xd6\x1b\x14\n\x12\x44riveSerialRemoved\x12\x36\n\x1a\x43OUNTER_DRIVE_SERIAL_ERROR\x10\x0c\x1a\x16\x82\xd6\x1b\x12\n\x10\x44riveSerialError\x12H\n$COUNTER_DISK_SCRUB_WAITING_FOR_START\x10\r\x1a\x1e\x82\xd6\x1b\x1a\n\x18\x44iskScrubWaitingForStart\x12\x36\n\x1a\x43OUNTER_DISK_SCRUB_RUNNING\x10\x0e\x1a\x16\x82\xd6\x1b\x12\n\x10\x44iskScrubRunning\x12=\n\x1e\x43OUNTER_DISK_SCRUB_IN_PROGRESS\x10\x0f\x1a\x19\x82\xd6\x1b\x15\n\x13\x44iskScrubInProgress\x12=\n\x1e\x43OUNTER_DISK_SCRUB_FINISHED_OK\x10\x10\x1a\x19\x82\xd6\x1b\x15\n\x13\x44iskScrubFinishedOk\x12?\n\x1f\x43OUNTER_DISK_SCRUB_FINISHED_ERR\x10\x11\x1a\x1a\x82\xd6\x1b\x16\n\x14\x44iskScrubFinishedErr\x12>\n\x1c\x43OUNTER_DISK_SCRUB_CUR_DISKS\x10\x12\x1a\x1c\x82\xd6\x1b\x18\n\x16\x43urrentlyScrubbedDisks\x12@\n\x1d\x43OUNTER_DISK_SCRUB_CUR_GROUPS\x10\x13\x1a\x1d\x82\xd6\x1b\x19\n\x17\x43urrentlyScrubbedGroups\x12O\n\'COUNTER_SELF_HEAL_UNREASSIGNABLE_GROUPS\x10\x14\x1a\"\x82\xd6\x1b\x1e\n\x1cSelfHealUnreassignableGroups*\xfc\x13\n\x13\x45\x43umulativeCounters\x12\x38\n\x1b\x43OUNTER_REGISTER_NODE_COUNT\x10\x00\x1a\x17\x82\xd6\x1b\x13\n\x11RegisterNodeCount\x12:\n\x1a\x43OUNTER_REGISTER_NODE_USEC\x10\x01\x1a\x1a\x82\xd6\x1b\x16\n\x14RegisterNodeMicrosec\x12\x30\n\x17\x43OUNTER_GET_GROUP_COUNT\x10\x02\x1a\x13\x82\xd6\x1b\x0f\n\rGetGroupCount\x12\x32\n\x16\x43OUNTER_GET_GROUP_USEC\x10\x03\x1a\x16\x82\xd6\x1b\x12\n\x10GetGroupMicrosec\x12\x38\n\x1b\x43OUNTER_SELECT_GROUPS_COUNT\x10\x04\x1a\x17\x82\xd6\x1b\x13\n\x11SelectGroupsCount\x12:\n\x1a\x43OUNTER_SELECT_GROUPS_USEC\x10\x05\x1a\x1a\x82\xd6\x1b\x16\n\x14SelectGroupsMicrosec\x12\x43\n!COUNTER_UPDATE_DISK_METRICS_COUNT\x10\x06\x1a\x1c\x82\xd6\x1b\x18\n\x16UpdateDiskMetricsCount\x12\x45\n COUNTER_UPDATE_DISK_METRICS_USEC\x10\x07\x1a\x1f\x82\xd6\x1b\x1b\n\x19UpdateDiskMetricsMicrosec\x12\x34\n\x19\x43OUNTER_NODE_REPORT_COUNT\x10\x08\x1a\x15\x82\xd6\x1b\x11\n\x0fNodeReportCount\x12\x36\n\x18\x43OUNTER_NODE_REPORT_USEC\x10\t\x1a\x18\x82\xd6\x1b\x14\n\x12NodeReportMicrosec\x12+\n\x14\x43OUNTER_CONFIG_COUNT\x10\n\x1a\x11\x82\xd6\x1b\r\n\x0b\x43onfigCount\x12-\n\x13\x43OUNTER_CONFIG_USEC\x10\x0b\x1a\x14\x82\xd6\x1b\x10\n\x0e\x43onfigMicrosec\x12\x36\n\x1a\x43OUNTER_REQUEST_INFO_COUNT\x10\x0c\x1a\x16\x82\xd6\x1b\x12\n\x10RequestInfoCount\x12\x38\n\x19\x43OUNTER_REQUEST_INFO_USEC\x10\r\x1a\x19\x82\xd6\x1b\x15\n\x13RequestInfoMicrosec\x12M\n&COUNTER_SELFHEAL_REASSIGN_BSC_REQUESTS\x10\x0e\x1a!\x82\xd6\x1b\x1d\n\x1bSelfHealReassignBscRequests\x12\x41\n COUNTER_SELFHEAL_REASSIGN_BSC_OK\x10\x0f\x1a\x1b\x82\xd6\x1b\x17\n\x15SelfHealReassignBscOk\x12\x43\n!COUNTER_SELFHEAL_REASSIGN_BSC_ERR\x10\x10\x1a\x1c\x82\xd6\x1b\x18\n\x16SelfHealReassignBscErr\x12\x45\n)COUNTER_CONFIGCMD_DEFINE_HOST_CONFIG_USEC\x10\x11\x1a\x16\x82\xd6\x1b\x12\n\x10\x44\x65\x66ineHostConfig\x12\x41\n\'COUNTER_CONFIGCMD_READ_HOST_CONFIG_USEC\x10\x12\x1a\x14\x82\xd6\x1b\x10\n\x0eReadHostConfig\x12\x45\n)COUNTER_CONFIGCMD_DELETE_HOST_CONFIG_USEC\x10\x13\x1a\x16\x82\xd6\x1b\x12\n\x10\x44\x65leteHostConfig\x12\x36\n!COUNTER_CONFIGCMD_DEFINE_BOX_USEC\x10\x14\x1a\x0f\x82\xd6\x1b\x0b\n\tDefineBox\x12\x32\n\x1f\x43OUNTER_CONFIGCMD_READ_BOX_USEC\x10\x15\x1a\r\x82\xd6\x1b\t\n\x07ReadBox\x12\x36\n!COUNTER_CONFIGCMD_DELETE_BOX_USEC\x10\x16\x1a\x0f\x82\xd6\x1b\x0b\n\tDeleteBox\x12G\n*COUNTER_CONFIGCMD_DEFINE_STORAGE_POOL_USEC\x10\x17\x1a\x17\x82\xd6\x1b\x13\n\x11\x44\x65\x66ineStoragePool\x12\x43\n(COUNTER_CONFIGCMD_READ_STORAGE_POOL_USEC\x10\x18\x1a\x15\x82\xd6\x1b\x11\n\x0fReadStoragePool\x12G\n*COUNTER_CONFIGCMD_DELETE_STORAGE_POOL_USEC\x10\x19\x1a\x17\x82\xd6\x1b\x13\n\x11\x44\x65leteStoragePool\x12G\n*COUNTER_CONFIGCMD_UPDATE_DRIVE_STATUS_USEC\x10\x1a\x1a\x17\x82\xd6\x1b\x13\n\x11UpdateDriveStatus\x12\x43\n(COUNTER_CONFIGCMD_READ_DRIVE_STATUS_USEC\x10\x1b\x1a\x15\x82\xd6\x1b\x11\n\x0fReadDriveStatus\x12K\n,COUNTER_CONFIGCMD_PROPOSE_STORAGE_POOLS_USEC\x10\x1c\x1a\x19\x82\xd6\x1b\x15\n\x13ProposeStoragePools\x12\x43\n(COUNTER_CONFIGCMD_QUERY_BASE_CONFIG_USEC\x10\x1d\x1a\x15\x82\xd6\x1b\x11\n\x0fQueryBaseConfig\x12\x38\n\"COUNTER_CONFIGCMD_MERGE_BOXES_USEC\x10\x1e\x1a\x10\x82\xd6\x1b\x0c\n\nMergeBoxes\x12\x38\n\"COUNTER_CONFIGCMD_MOVE_GROUPS_USEC\x10\x1f\x1a\x10\x82\xd6\x1b\x0c\n\nMoveGroups\x12\x45\n)COUNTER_CONFIGCMD_ADD_MIGRATION_PLAN_USEC\x10 \x1a\x16\x82\xd6\x1b\x12\n\x10\x41\x64\x64MigrationPlan\x12K\n,COUNTER_CONFIGCMD_DELETE_MIGRATION_PLAN_USEC\x10!\x1a\x19\x82\xd6\x1b\x15\n\x13\x44\x65leteMigrationPlan\x12>\n%COUNTER_CONFIGCMD_DECLARE_INTENT_USEC\x10\"\x1a\x13\x82\xd6\x1b\x0f\n\rDeclareIntent\x12\x38\n\"COUNTER_CONFIGCMD_READ_INTENT_USEC\x10#\x1a\x10\x82\xd6\x1b\x0c\n\nReadIntent\x12?\n&COUNTER_CONFIGCMD_DROP_DONOR_DISK_USEC\x10$\x1a\x13\x82\xd6\x1b\x0f\n\rDropDonorDisk\x12G\n*COUNTER_CONFIGCMD_REASSIGN_GROUP_DISK_USEC\x10%\x1a\x17\x82\xd6\x1b\x13\n\x11ReassignGroupDisk\x12>\n#COUNTER_DISK_SCRUB_QUANTUM_FINISHED\x10&\x1a\x15\x82\xd6\x1b\x11\n\x0fQuantumFinished\x12<\n$COUNTER_CONFIGCMD_READ_SETTINGS_USEC\x10\'\x1a\x12\x82\xd6\x1b\x0e\n\x0cReadSettings*\xe6\n\n\x13\x45PercentileCounters\x12\x38\n COUNTER_PERCENTILE_SELECT_GROUPS\x10\x00\x1a\x12\x82\xd6\x1b\x0e\n\x0cSelectGroups\x12\xdd\x02\n\x1e\x43OUNTER_FAULTY_USETTLED_PDISKS\x10\x01\x1a\xb8\x02\x82\xd6\x1b\xb3\x02\n\x15\x46\x61ultyUnsettledPDisks\x12\x05\x08\x00\x12\x01\x30\x12\x06\x08\n\x12\x02\x31\x30\x12\x06\x08\x14\x12\x02\x32\x30\x12\x06\x08\x1e\x12\x02\x33\x30\x12\x06\x08(\x12\x02\x34\x30\x12\x06\x08\x32\x12\x02\x35\x30\x12\x06\x08<\x12\x02\x36\x30\x12\x07\x08x\x12\x03\x31\x32\x30\x12\x08\x08\xb4\x01\x12\x03\x31\x38\x30\x12\x08\x08\xf0\x01\x12\x03\x32\x34\x30\x12\x08\x08\xac\x02\x12\x03\x33\x30\x30\x12\x08\x08\xe8\x02\x12\x03\x33\x36\x30\x12\x08\x08\xa4\x03\x12\x03\x34\x32\x30\x12\x08\x08\xe0\x03\x12\x03\x34\x38\x30\x12\x08\x08\x9c\x04\x12\x03\x35\x34\x30\x12\x08\x08\xd8\x04\x12\x03\x36\x30\x30\x12\t\x08\xb0\t\x12\x04\x31\x32\x30\x30\x12\t\x08\x88\x0e\x12\x04\x31\x38\x30\x30\x12\t\x08\xe0\x12\x12\x04\x32\x34\x30\x30\x12\t\x08\xb8\x17\x12\x04\x33\x30\x30\x30\x12\t\x08\x90\x1c\x12\x04\x33\x36\x30\x30\x12\t\x08\x98*\x12\x04\x35\x34\x30\x30\x12\t\x08\xa0\x38\x12\x04\x37\x32\x30\x30\x12\t\x08\xa8\x46\x12\x04\x39\x30\x30\x30\x12\n\x08\xb0T\x12\x05\x31\x30\x38\x30\x30\x12\n\x08\xc0p\x12\x05\x31\x34\x34\x30\x30\x12\x0b\x08\xd0\x8c\x01\x12\x05\x31\x38\x30\x30\x30\x12\x0b\x08\xe0\xa8\x01\x12\x05\x32\x31\x36\x30\x30\x18\x01\x12\xe9\x02\n%COUNTER_TO_BE_REMOVED_USETTLED_PDISKS\x10\x02\x1a\xbd\x02\x82\xd6\x1b\xb8\x02\n\x1aToBeRemovedUnsettledPDisks\x12\x05\x08\x00\x12\x01\x30\x12\x06\x08\n\x12\x02\x31\x30\x12\x06\x08\x14\x12\x02\x32\x30\x12\x06\x08\x1e\x12\x02\x33\x30\x12\x06\x08(\x12\x02\x34\x30\x12\x06\x08\x32\x12\x02\x35\x30\x12\x06\x08<\x12\x02\x36\x30\x12\x07\x08x\x12\x03\x31\x32\x30\x12\x08\x08\xb4\x01\x12\x03\x31\x38\x30\x12\x08\x08\xf0\x01\x12\x03\x32\x34\x30\x12\x08\x08\xac\x02\x12\x03\x33\x30\x30\x12\x08\x08\xe8\x02\x12\x03\x33\x36\x30\x12\x08\x08\xa4\x03\x12\x03\x34\x32\x30\x12\x08\x08\xe0\x03\x12\x03\x34\x38\x30\x12\x08\x08\x9c\x04\x12\x03\x35\x34\x30\x12\x08\x08\xd8\x04\x12\x03\x36\x30\x30\x12\t\x08\xb0\t\x12\x04\x31\x32\x30\x30\x12\t\x08\x88\x0e\x12\x04\x31\x38\x30\x30\x12\t\x08\xe0\x12\x12\x04\x32\x34\x30\x30\x12\t\x08\xb8\x17\x12\x04\x33\x30\x30\x30\x12\t\x08\x90\x1c\x12\x04\x33\x36\x30\x30\x12\t\x08\x98*\x12\x04\x35\x34\x30\x30\x12\t\x08\xa0\x38\x12\x04\x37\x32\x30\x30\x12\t\x08\xa8\x46\x12\x04\x39\x30\x30\x30\x12\n\x08\xb0T\x12\x05\x31\x30\x38\x30\x30\x12\n\x08\xc0p\x12\x05\x31\x34\x34\x30\x30\x12\x0b\x08\xd0\x8c\x01\x12\x05\x31\x38\x30\x30\x30\x12\x0b\x08\xe0\xa8\x01\x12\x05\x32\x31\x36\x30\x30\x18\x01\x12\xea\x01\n\x1c\x43OUNTER_NUM_NOT_READY_VDISKS\x10\x03\x1a\xc7\x01\x82\xd6\x1b\xc2\x01\n\x11NumNotReadyVDisks\x12\x05\x08\x00\x12\x01\x30\x12\x06\x08<\x12\x02\x36\x30\x12\x08\x08\xac\x02\x12\x03\x33\x30\x30\x12\x08\x08\xd8\x04\x12\x03\x36\x30\x30\x12\t\x08\xb0\t\x12\x04\x31\x32\x30\x30\x12\t\x08\x88\x0e\x12\x04\x31\x38\x30\x30\x12\t\x08\xe0\x12\x12\x04\x32\x34\x30\x30\x12\t\x08\xb8\x17\x12\x04\x33\x30\x30\x30\x12\t\x08\x90\x1c\x12\x04\x33\x36\x30\x30\x12\t\x08\x98*\x12\x04\x35\x34\x30\x30\x12\t\x08\xa0\x38\x12\x04\x37\x32\x30\x30\x12\t\x08\xa8\x46\x12\x04\x39\x30\x30\x30\x12\n\x08\xb0T\x12\x05\x31\x30\x38\x30\x30\x12\n\x08\xc0p\x12\x05\x31\x34\x34\x30\x30\x12\x0b\x08\xd0\x8c\x01\x12\x05\x31\x38\x30\x30\x30\x12\x0b\x08\xe0\xa8\x01\x12\x05\x32\x31\x36\x30\x30\x18\x01\x1a\xdb\x02\x92\xd6\x1b\xd6\x02\x12\x11\x08\xf4\x03\x12\x0c(1) < 500 us\x12\x11\x08\xe8\x07\x12\x0c(2) 0.5-1 ms\x12\x0f\x08\xd0\x0f\x12\n(3) 1-2 ms\x12\x0f\x08\xa0\x1f\x12\n(4) 2-4 ms\x12\x0f\x08\xc0>\x12\n(5) 4-8 ms\x12\x10\x08\x80}\x12\x0b(6) 8-16 ms\x12\x12\x08\x80\xfa\x01\x12\x0c(7) 16-32 ms\x12\x12\x08\x80\xf4\x03\x12\x0c(8) 32-64 ms\x12\x13\x08\x80\xe8\x07\x12\r(9) 64-128 ms\x12\x15\x08\x80\xd0\x0f\x12\x0f(10) 128-256 ms\x12\x15\x08\x80\xa0\x1f\x12\x0f(11) 256-512 ms\x12\x16\x08\x80\xc0>\x12\x10(12) 512-1024 ms\x12\x17\x08\x80\x89z\x12\x11(13) 1024-2000 ms\x12\x11\x08\x80\x92\xf4\x01\x12\n(14) 2-4 s\x12\x11\x08\x80\xa4\xe8\x03\x12\n(15) 4-8 s\x12\x12\x08\x80\xc8\xd0\x07\x12\x0b(16) 8-16 s\x12\x13\x08\x80\x90\xa1\x0f\x12\x0c(17) 16-32 s*\xec\x0b\n\x08\x45TxTypes\x12+\n\x12TXTYPE_INIT_SCHEME\x10\x00\x1a\x13\x8a\xd6\x1b\x0f\n\rTTxInitScheme\x12$\n\x0eTXTYPE_MIGRATE\x10\x01\x1a\x10\x8a\xd6\x1b\x0c\n\nTTxMigrate\x12\x33\n\x16TXTYPE_LOAD_EVERYTHING\x10\x02\x1a\x17\x8a\xd6\x1b\x13\n\x11TTxLoadEverything\x12\x42\n\x1eTXTYPE_MON_EVENT_OPERATION_LOG\x10\x03\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TTxMonEvent_OperationLog\x12\x38\n\x19TXTYPE_MON_EVENT_SET_DOWN\x10\x04\x1a\x19\x8a\xd6\x1b\x15\n\x13TTxMonEvent_SetDown\x12\x38\n\x19TXTYPE_MON_EVENT_GET_DOWN\x10\x05\x1a\x19\x8a\xd6\x1b\x15\n\x13TTxMonEvent_GetDown\x12:\n\x1aTXTYPE_UPDATE_DISK_METRICS\x10\x06\x1a\x1a\x8a\xd6\x1b\x16\n\x14TTxUpdateDiskMetrics\x12@\n\x1dTXTYPE_UPDATE_GROUP_LATENCIES\x10\x07\x1a\x1d\x8a\xd6\x1b\x19\n\x17TTxUpdateGroupLatencies\x12@\n\x1dTXTYPE_GROUP_RECONFIGURE_WIPE\x10\x08\x1a\x1d\x8a\xd6\x1b\x19\n\x17TTxGroupReconfigureWipe\x12+\n\x12TXTYPE_NODE_REPORT\x10\t\x1a\x13\x8a\xd6\x1b\x0f\n\rTTxNodeReport\x12\x42\n\x1eTXTYPE_UPDATE_SEEN_OPERATIONAL\x10\n\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TTxUpdateSeenOperational\x12)\n\x11TXTYPE_CONFIG_CMD\x10\x0b\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTTxConfigCmd\x12\x36\n\x18TXTYPE_PROPOSE_GROUP_KEY\x10\x0c\x1a\x18\x8a\xd6\x1b\x14\n\x12TTxProposeGroupKey\x12/\n\x14TXTYPE_REGISTER_NODE\x10\r\x1a\x15\x8a\xd6\x1b\x11\n\x0fTTxRegisterNode\x12\'\n\x10TXTYPE_GET_GROUP\x10\x0e\x1a\x11\x8a\xd6\x1b\r\n\x0bTTxGetGroup\x12\x42\n\x1eTXTYPE_REQUEST_CONTROLLER_INFO\x10\x0f\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TTxRequestControllerInfo\x12/\n\x14TXTYPE_SELECT_GROUPS\x10\x10\x1a\x15\x8a\xd6\x1b\x11\n\x0fTTxSelectGroups\x12\x42\n\x1eTXTYPE_MON_EVENT_HEALTH_EVENTS\x10\x11\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TTxMonEvent_HealthEvents\x12)\n\x11TXTYPE_DROP_DONOR\x10\x12\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTTxDropDonor\x12+\n\x12TXTYPE_SCRUB_START\x10\x13\x1a\x13\x8a\xd6\x1b\x0f\n\rTTxScrubStart\x12@\n\x1dTXTYPE_SCRUB_QUANTUM_FINISHED\x10\x14\x1a\x1d\x8a\xd6\x1b\x19\n\x17TTxScrubQuantumFinished\x12?\n\x1dTXTYPE_UPDATE_LAST_SEEN_READY\x10\x15\x1a\x1c\x8a\xd6\x1b\x18\n\x16TTxUpdateLastSeenReady\x12\x38\n\x19TXTYPE_UPDATE_NODE_DRIVES\x10\x16\x1a\x19\x8a\xd6\x1b\x15\n\x13TTxUpdateNodeDrives\x12M\n$TXTYPE_MON_EVENT_OPERATION_LOG_ENTRY\x10\x17\x1a#\x8a\xd6\x1b\x1f\n\x1dTTxMonEvent_OperationLogEntry\x12S\n\'TXTYPE_UPDATE_NODE_DISCONNECT_TIMESTAMP\x10\x18\x1a&\x8a\xd6\x1b\"\n TTxUpdateNodeDisconnectTimestamp\x12@\n\x1dTXTYPE_GROUP_METRICS_EXCHANGE\x10\x19\x1a\x1d\x8a\xd6\x1b\x19\n\x17TTxGroupMetricsExchangeB(\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x0c\x42SController')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_bs_controller_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\014BSController'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_RESPONSE_TIME_USEC"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_RESPONSE_TIME_USEC"]._serialized_options = b'\202\326\033\026\n\024ResponseTimeMicrosec'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_GROUPS_WITH_SLOTS_ON_FAULTY_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_GROUPS_WITH_SLOTS_ON_FAULTY_DISKS"]._serialized_options = b'\202\326\033\036\n\034GroupsWithSlotsOnFaultyDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SLOTS_ON_FAULTY_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SLOTS_ON_FAULTY_DISKS"]._serialized_options = b'\202\326\033\024\n\022SlotsOnFaultyDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BYTES_ON_FAULTY_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BYTES_ON_FAULTY_DISKS"]._serialized_options = b'\202\326\033\024\n\022BytesOnFaultyDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PDISKS_WITHOUT_EXPECTED_SLOT_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PDISKS_WITHOUT_EXPECTED_SLOT_COUNT"]._serialized_options = b'\202\326\033 \n\036PDisksWithoutExpectedSlotCount'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TO_BE_REMOVED_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TO_BE_REMOVED_DISKS"]._serialized_options = b'\202\326\033\022\n\020ToBeRemovedDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_GROUPS_WITH_SLOTS_ON_TO_BE_REMOVED_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_GROUPS_WITH_SLOTS_ON_TO_BE_REMOVED_DISKS"]._serialized_options = b'\202\326\033#\n!GroupsWithSlotsOnToBeRemovedDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SLOTS_ON_TO_BE_REMOVED_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SLOTS_ON_TO_BE_REMOVED_DISKS"]._serialized_options = b'\202\326\033\031\n\027SlotsOnToBeRemovedDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BYTES_ON_TO_BE_REMOVED_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BYTES_ON_TO_BE_REMOVED_DISKS"]._serialized_options = b'\202\326\033\031\n\027BytesOnToBeRemovedDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PDISKS_WITHOUT_EXPECTED_SERIAL"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PDISKS_WITHOUT_EXPECTED_SERIAL"]._serialized_options = b'\202\326\033\035\n\033PDisksWithoutExpectedSerial'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DRIVE_SERIAL_NOT_SEEN"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DRIVE_SERIAL_NOT_SEEN"]._serialized_options = b'\202\326\033\024\n\022DriveSerialNotSeen'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DRIVE_SERIAL_REMOVED"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DRIVE_SERIAL_REMOVED"]._serialized_options = b'\202\326\033\024\n\022DriveSerialRemoved'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DRIVE_SERIAL_ERROR"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DRIVE_SERIAL_ERROR"]._serialized_options = b'\202\326\033\022\n\020DriveSerialError'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_WAITING_FOR_START"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_WAITING_FOR_START"]._serialized_options = b'\202\326\033\032\n\030DiskScrubWaitingForStart'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_RUNNING"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_RUNNING"]._serialized_options = b'\202\326\033\022\n\020DiskScrubRunning'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_IN_PROGRESS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_IN_PROGRESS"]._serialized_options = b'\202\326\033\025\n\023DiskScrubInProgress'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_FINISHED_OK"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_FINISHED_OK"]._serialized_options = b'\202\326\033\025\n\023DiskScrubFinishedOk'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_FINISHED_ERR"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_FINISHED_ERR"]._serialized_options = b'\202\326\033\026\n\024DiskScrubFinishedErr'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_CUR_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_CUR_DISKS"]._serialized_options = b'\202\326\033\030\n\026CurrentlyScrubbedDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_CUR_GROUPS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_CUR_GROUPS"]._serialized_options = b'\202\326\033\031\n\027CurrentlyScrubbedGroups'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SELF_HEAL_UNREASSIGNABLE_GROUPS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SELF_HEAL_UNREASSIGNABLE_GROUPS"]._serialized_options = b'\202\326\033\036\n\034SelfHealUnreassignableGroups'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REGISTER_NODE_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REGISTER_NODE_COUNT"]._serialized_options = b'\202\326\033\023\n\021RegisterNodeCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REGISTER_NODE_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REGISTER_NODE_USEC"]._serialized_options = b'\202\326\033\026\n\024RegisterNodeMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_GET_GROUP_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_GET_GROUP_COUNT"]._serialized_options = b'\202\326\033\017\n\rGetGroupCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_GET_GROUP_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_GET_GROUP_USEC"]._serialized_options = b'\202\326\033\022\n\020GetGroupMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELECT_GROUPS_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELECT_GROUPS_COUNT"]._serialized_options = b'\202\326\033\023\n\021SelectGroupsCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELECT_GROUPS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELECT_GROUPS_USEC"]._serialized_options = b'\202\326\033\026\n\024SelectGroupsMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPDATE_DISK_METRICS_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPDATE_DISK_METRICS_COUNT"]._serialized_options = b'\202\326\033\030\n\026UpdateDiskMetricsCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPDATE_DISK_METRICS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPDATE_DISK_METRICS_USEC"]._serialized_options = b'\202\326\033\033\n\031UpdateDiskMetricsMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_NODE_REPORT_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_NODE_REPORT_COUNT"]._serialized_options = b'\202\326\033\021\n\017NodeReportCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_NODE_REPORT_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_NODE_REPORT_USEC"]._serialized_options = b'\202\326\033\024\n\022NodeReportMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIG_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIG_COUNT"]._serialized_options = b'\202\326\033\r\n\013ConfigCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIG_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIG_USEC"]._serialized_options = b'\202\326\033\020\n\016ConfigMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQUEST_INFO_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQUEST_INFO_COUNT"]._serialized_options = b'\202\326\033\022\n\020RequestInfoCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQUEST_INFO_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQUEST_INFO_USEC"]._serialized_options = b'\202\326\033\025\n\023RequestInfoMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELFHEAL_REASSIGN_BSC_REQUESTS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELFHEAL_REASSIGN_BSC_REQUESTS"]._serialized_options = b'\202\326\033\035\n\033SelfHealReassignBscRequests'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELFHEAL_REASSIGN_BSC_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELFHEAL_REASSIGN_BSC_OK"]._serialized_options = b'\202\326\033\027\n\025SelfHealReassignBscOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELFHEAL_REASSIGN_BSC_ERR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELFHEAL_REASSIGN_BSC_ERR"]._serialized_options = b'\202\326\033\030\n\026SelfHealReassignBscErr'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DEFINE_HOST_CONFIG_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DEFINE_HOST_CONFIG_USEC"]._serialized_options = b'\202\326\033\022\n\020DefineHostConfig'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_HOST_CONFIG_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_HOST_CONFIG_USEC"]._serialized_options = b'\202\326\033\020\n\016ReadHostConfig'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_HOST_CONFIG_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_HOST_CONFIG_USEC"]._serialized_options = b'\202\326\033\022\n\020DeleteHostConfig'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DEFINE_BOX_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DEFINE_BOX_USEC"]._serialized_options = b'\202\326\033\013\n\tDefineBox'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_BOX_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_BOX_USEC"]._serialized_options = b'\202\326\033\t\n\007ReadBox'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_BOX_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_BOX_USEC"]._serialized_options = b'\202\326\033\013\n\tDeleteBox'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DEFINE_STORAGE_POOL_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DEFINE_STORAGE_POOL_USEC"]._serialized_options = b'\202\326\033\023\n\021DefineStoragePool'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_STORAGE_POOL_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_STORAGE_POOL_USEC"]._serialized_options = b'\202\326\033\021\n\017ReadStoragePool'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_STORAGE_POOL_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_STORAGE_POOL_USEC"]._serialized_options = b'\202\326\033\023\n\021DeleteStoragePool'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_UPDATE_DRIVE_STATUS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_UPDATE_DRIVE_STATUS_USEC"]._serialized_options = b'\202\326\033\023\n\021UpdateDriveStatus'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_DRIVE_STATUS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_DRIVE_STATUS_USEC"]._serialized_options = b'\202\326\033\021\n\017ReadDriveStatus'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_PROPOSE_STORAGE_POOLS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_PROPOSE_STORAGE_POOLS_USEC"]._serialized_options = b'\202\326\033\025\n\023ProposeStoragePools'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_QUERY_BASE_CONFIG_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_QUERY_BASE_CONFIG_USEC"]._serialized_options = b'\202\326\033\021\n\017QueryBaseConfig'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_MERGE_BOXES_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_MERGE_BOXES_USEC"]._serialized_options = b'\202\326\033\014\n\nMergeBoxes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_MOVE_GROUPS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_MOVE_GROUPS_USEC"]._serialized_options = b'\202\326\033\014\n\nMoveGroups'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_ADD_MIGRATION_PLAN_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_ADD_MIGRATION_PLAN_USEC"]._serialized_options = b'\202\326\033\022\n\020AddMigrationPlan'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_MIGRATION_PLAN_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_MIGRATION_PLAN_USEC"]._serialized_options = b'\202\326\033\025\n\023DeleteMigrationPlan'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DECLARE_INTENT_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DECLARE_INTENT_USEC"]._serialized_options = b'\202\326\033\017\n\rDeclareIntent'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_INTENT_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_INTENT_USEC"]._serialized_options = b'\202\326\033\014\n\nReadIntent'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DROP_DONOR_DISK_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DROP_DONOR_DISK_USEC"]._serialized_options = b'\202\326\033\017\n\rDropDonorDisk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_REASSIGN_GROUP_DISK_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_REASSIGN_GROUP_DISK_USEC"]._serialized_options = b'\202\326\033\023\n\021ReassignGroupDisk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_QUANTUM_FINISHED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_QUANTUM_FINISHED"]._serialized_options = b'\202\326\033\021\n\017QuantumFinished'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_SETTINGS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_SETTINGS_USEC"]._serialized_options = b'\202\326\033\016\n\014ReadSettings'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\326\002\022\021\010\364\003\022\014(1) < 500 us\022\021\010\350\007\022\014(2) 0.5-1 ms\022\017\010\320\017\022\n(3) 1-2 ms\022\017\010\240\037\022\n(4) 2-4 ms\022\017\010\300>\022\n(5) 4-8 ms\022\020\010\200}\022\013(6) 8-16 ms\022\022\010\200\372\001\022\014(7) 16-32 ms\022\022\010\200\364\003\022\014(8) 32-64 ms\022\023\010\200\350\007\022\r(9) 64-128 ms\022\025\010\200\320\017\022\017(10) 128-256 ms\022\025\010\200\240\037\022\017(11) 256-512 ms\022\026\010\200\300>\022\020(12) 512-1024 ms\022\027\010\200\211z\022\021(13) 1024-2000 ms\022\021\010\200\222\364\001\022\n(14) 2-4 s\022\021\010\200\244\350\003\022\n(15) 4-8 s\022\022\010\200\310\320\007\022\013(16) 8-16 s\022\023\010\200\220\241\017\022\014(17) 16-32 s'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PERCENTILE_SELECT_GROUPS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PERCENTILE_SELECT_GROUPS"]._serialized_options = b'\202\326\033\016\n\014SelectGroups'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_FAULTY_USETTLED_PDISKS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_FAULTY_USETTLED_PDISKS"]._serialized_options = b'\202\326\033\263\002\n\025FaultyUnsettledPDisks\022\005\010\000\022\0010\022\006\010\n\022\00210\022\006\010\024\022\00220\022\006\010\036\022\00230\022\006\010(\022\00240\022\006\0102\022\00250\022\006\010<\022\00260\022\007\010x\022\003120\022\010\010\264\001\022\003180\022\010\010\360\001\022\003240\022\010\010\254\002\022\003300\022\010\010\350\002\022\003360\022\010\010\244\003\022\003420\022\010\010\340\003\022\003480\022\010\010\234\004\022\003540\022\010\010\330\004\022\003600\022\t\010\260\t\022\0041200\022\t\010\210\016\022\0041800\022\t\010\340\022\022\0042400\022\t\010\270\027\022\0043000\022\t\010\220\034\022\0043600\022\t\010\230*\022\0045400\022\t\010\2408\022\0047200\022\t\010\250F\022\0049000\022\n\010\260T\022\00510800\022\n\010\300p\022\00514400\022\013\010\320\214\001\022\00518000\022\013\010\340\250\001\022\00521600\030\001'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_TO_BE_REMOVED_USETTLED_PDISKS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_TO_BE_REMOVED_USETTLED_PDISKS"]._serialized_options = b'\202\326\033\270\002\n\032ToBeRemovedUnsettledPDisks\022\005\010\000\022\0010\022\006\010\n\022\00210\022\006\010\024\022\00220\022\006\010\036\022\00230\022\006\010(\022\00240\022\006\0102\022\00250\022\006\010<\022\00260\022\007\010x\022\003120\022\010\010\264\001\022\003180\022\010\010\360\001\022\003240\022\010\010\254\002\022\003300\022\010\010\350\002\022\003360\022\010\010\244\003\022\003420\022\010\010\340\003\022\003480\022\010\010\234\004\022\003540\022\010\010\330\004\022\003600\022\t\010\260\t\022\0041200\022\t\010\210\016\022\0041800\022\t\010\340\022\022\0042400\022\t\010\270\027\022\0043000\022\t\010\220\034\022\0043600\022\t\010\230*\022\0045400\022\t\010\2408\022\0047200\022\t\010\250F\022\0049000\022\n\010\260T\022\00510800\022\n\010\300p\022\00514400\022\013\010\320\214\001\022\00518000\022\013\010\340\250\001\022\00521600\030\001'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_NUM_NOT_READY_VDISKS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_NUM_NOT_READY_VDISKS"]._serialized_options = b'\202\326\033\302\001\n\021NumNotReadyVDisks\022\005\010\000\022\0010\022\006\010<\022\00260\022\010\010\254\002\022\003300\022\010\010\330\004\022\003600\022\t\010\260\t\022\0041200\022\t\010\210\016\022\0041800\022\t\010\340\022\022\0042400\022\t\010\270\027\022\0043000\022\t\010\220\034\022\0043600\022\t\010\230*\022\0045400\022\t\010\2408\022\0047200\022\t\010\250F\022\0049000\022\n\010\260T\022\00510800\022\n\010\300p\022\00514400\022\013\010\320\214\001\022\00518000\022\013\010\340\250\001\022\00521600\030\001'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEME"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEME"]._serialized_options = b'\212\326\033\017\n\rTTxInitScheme'
  _ETXTYPES.values_by_name["TXTYPE_MIGRATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MIGRATE"]._serialized_options = b'\212\326\033\014\n\nTTxMigrate'
  _ETXTYPES.values_by_name["TXTYPE_LOAD_EVERYTHING"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LOAD_EVERYTHING"]._serialized_options = b'\212\326\033\023\n\021TTxLoadEverything'
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_OPERATION_LOG"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_OPERATION_LOG"]._serialized_options = b'\212\326\033\032\n\030TTxMonEvent_OperationLog'
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_SET_DOWN"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_SET_DOWN"]._serialized_options = b'\212\326\033\025\n\023TTxMonEvent_SetDown'
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_GET_DOWN"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_GET_DOWN"]._serialized_options = b'\212\326\033\025\n\023TTxMonEvent_GetDown'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_DISK_METRICS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_DISK_METRICS"]._serialized_options = b'\212\326\033\026\n\024TTxUpdateDiskMetrics'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_GROUP_LATENCIES"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_GROUP_LATENCIES"]._serialized_options = b'\212\326\033\031\n\027TTxUpdateGroupLatencies'
  _ETXTYPES.values_by_name["TXTYPE_GROUP_RECONFIGURE_WIPE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GROUP_RECONFIGURE_WIPE"]._serialized_options = b'\212\326\033\031\n\027TTxGroupReconfigureWipe'
  _ETXTYPES.values_by_name["TXTYPE_NODE_REPORT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_NODE_REPORT"]._serialized_options = b'\212\326\033\017\n\rTTxNodeReport'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_SEEN_OPERATIONAL"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_SEEN_OPERATIONAL"]._serialized_options = b'\212\326\033\032\n\030TTxUpdateSeenOperational'
  _ETXTYPES.values_by_name["TXTYPE_CONFIG_CMD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CONFIG_CMD"]._serialized_options = b'\212\326\033\016\n\014TTxConfigCmd'
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE_GROUP_KEY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE_GROUP_KEY"]._serialized_options = b'\212\326\033\024\n\022TTxProposeGroupKey'
  _ETXTYPES.values_by_name["TXTYPE_REGISTER_NODE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REGISTER_NODE"]._serialized_options = b'\212\326\033\021\n\017TTxRegisterNode'
  _ETXTYPES.values_by_name["TXTYPE_GET_GROUP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GET_GROUP"]._serialized_options = b'\212\326\033\r\n\013TTxGetGroup'
  _ETXTYPES.values_by_name["TXTYPE_REQUEST_CONTROLLER_INFO"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REQUEST_CONTROLLER_INFO"]._serialized_options = b'\212\326\033\032\n\030TTxRequestControllerInfo'
  _ETXTYPES.values_by_name["TXTYPE_SELECT_GROUPS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SELECT_GROUPS"]._serialized_options = b'\212\326\033\021\n\017TTxSelectGroups'
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_HEALTH_EVENTS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_HEALTH_EVENTS"]._serialized_options = b'\212\326\033\032\n\030TTxMonEvent_HealthEvents'
  _ETXTYPES.values_by_name["TXTYPE_DROP_DONOR"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DROP_DONOR"]._serialized_options = b'\212\326\033\016\n\014TTxDropDonor'
  _ETXTYPES.values_by_name["TXTYPE_SCRUB_START"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SCRUB_START"]._serialized_options = b'\212\326\033\017\n\rTTxScrubStart'
  _ETXTYPES.values_by_name["TXTYPE_SCRUB_QUANTUM_FINISHED"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SCRUB_QUANTUM_FINISHED"]._serialized_options = b'\212\326\033\031\n\027TTxScrubQuantumFinished'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_LAST_SEEN_READY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_LAST_SEEN_READY"]._serialized_options = b'\212\326\033\030\n\026TTxUpdateLastSeenReady'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_NODE_DRIVES"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_NODE_DRIVES"]._serialized_options = b'\212\326\033\025\n\023TTxUpdateNodeDrives'
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_OPERATION_LOG_ENTRY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_OPERATION_LOG_ENTRY"]._serialized_options = b'\212\326\033\037\n\035TTxMonEvent_OperationLogEntry'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_NODE_DISCONNECT_TIMESTAMP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_NODE_DISCONNECT_TIMESTAMP"]._serialized_options = b'\212\326\033\"\n TTxUpdateNodeDisconnectTimestamp'
  _ETXTYPES.values_by_name["TXTYPE_GROUP_METRICS_EXCHANGE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GROUP_METRICS_EXCHANGE"]._serialized_options = b'\212\326\033\031\n\027TTxGroupMetricsExchange'
  _ESIMPLECOUNTERS._serialized_start=113
  _ESIMPLECOUNTERS._serialized_end=1567
  _ECUMULATIVECOUNTERS._serialized_start=1570
  _ECUMULATIVECOUNTERS._serialized_end=4126
  _EPERCENTILECOUNTERS._serialized_start=4129
  _EPERCENTILECOUNTERS._serialized_end=5511
  _ETXTYPES._serialized_start=5514
  _ETXTYPES._serialized_end=7030
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_replication.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ydb/core/protos/counters_replication.proto\x12\x14NKikimr.NReplication\x1a\x1eydb/core/protos/counters.proto*,\n\x0f\x45SimpleCounters\x12\x19\n\x15\x43OUNTER_SIMPLE_IGNORE\x10\x00*4\n\x13\x45\x43umulativeCounters\x12\x1d\n\x19\x43OUNTER_CUMULATIVE_IGNORE\x10\x00*N\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x1a\x18\x92\xd6\x1b\x14\x12\x08\x08\x00\x12\x04\x30 ms\x12\x08\x08\x01\x12\x04\x31 ms*\xa8\x03\n\x08\x45TxTypes\x12*\n\x12TXTYPE_INIT_SCHEMA\x10\x00\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxInitSchema\x12\x1d\n\x0bTXTYPE_INIT\x10\x01\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12\x38\n\x19TXTYPE_CREATE_REPLICATION\x10\x02\x1a\x19\x8a\xd6\x1b\x15\n\x13TxCreateReplication\x12\x34\n\x17TXTYPE_DROP_REPLICATION\x10\x03\x1a\x17\x8a\xd6\x1b\x13\n\x11TxDropReplication\x12\x34\n\x17TXTYPE_DISCOVERY_RESULT\x10\x04\x1a\x17\x8a\xd6\x1b\x13\n\x11TxDiscoveryResult\x12\x37\n\x19TXTYPE_ASSIGN_STREAM_NAME\x10\x05\x1a\x18\x8a\xd6\x1b\x14\n\x12TxAssignStreamName\x12;\n\x1bTXTYPE_CREATE_STREAM_RESULT\x10\x06\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxCreateStreamResult\x12\x35\n\x18TXTYPE_CREATE_DST_RESULT\x10\x07\x1a\x17\x8a\xd6\x1b\x13\n\x11TxCreateDstResultB1\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x15ReplicationController')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_replication_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\025ReplicationController'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\024\022\010\010\000\022\0040 ms\022\010\010\001\022\0041 ms'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._serialized_options = b'\212\326\033\016\n\014TxInitSchema'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_REPLICATION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_REPLICATION"]._serialized_options = b'\212\326\033\025\n\023TxCreateReplication'
  _ETXTYPES.values_by_name["TXTYPE_DROP_REPLICATION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DROP_REPLICATION"]._serialized_options = b'\212\326\033\023\n\021TxDropReplication'
  _ETXTYPES.values_by_name["TXTYPE_DISCOVERY_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DISCOVERY_RESULT"]._serialized_options = b'\212\326\033\023\n\021TxDiscoveryResult'
  _ETXTYPES.values_by_name["TXTYPE_ASSIGN_STREAM_NAME"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ASSIGN_STREAM_NAME"]._serialized_options = b'\212\326\033\024\n\022TxAssignStreamName'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_STREAM_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_STREAM_RESULT"]._serialized_options = b'\212\326\033\026\n\024TxCreateStreamResult'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_DST_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_DST_RESULT"]._serialized_options = b'\212\326\033\023\n\021TxCreateDstResult'
  _ESIMPLECOUNTERS._serialized_start=100
  _ESIMPLECOUNTERS._serialized_end=144
  _ECUMULATIVECOUNTERS._serialized_start=146
  _ECUMULATIVECOUNTERS._serialized_end=198
  _EPERCENTILECOUNTERS._serialized_start=200
  _EPERCENTILECOUNTERS._serialized_end=278
  _ETXTYPES._serialized_start=281
  _ETXTYPES._serialized_end=705
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/kqp.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import type_info_pb2 as ydb_dot_core_dot_protos_dot_type__info__pb2
from ydb.core.protos import kqp_physical_pb2 as ydb_dot_core_dot_protos_dot_kqp__physical__pb2
from ydb.core.protos import kqp_stats_pb2 as ydb_dot_core_dot_protos_dot_kqp__stats__pb2
from ydb.core.protos import query_stats_pb2 as ydb_dot_core_dot_protos_dot_query__stats__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2
from ydb.public.api.protos import ydb_table_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__table__pb2
from ydb.public.api.protos import ydb_value_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__value__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.public.api.protos import ydb_topic_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__topic__pb2
from ydb.library.mkql_proto.protos import minikql_pb2 as ydb_dot_library_dot_mkql__proto_dot_protos_dot_minikql__pb2
from ydb.library.yql.dq.actors.protos import dq_events_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_actors_dot_protos_dot_dq__events__pb2
from ydb.library.yql.dq.actors.protos import dq_stats_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_actors_dot_protos_dot_dq__stats__pb2
from ydb.library.yql.dq.proto import dq_tasks_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_proto_dot_dq__tasks__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ydb/core/protos/kqp.proto\x12\nNKikimrKqp\x1a&library/cpp/actors/protos/actors.proto\x1a\x1fydb/core/protos/type_info.proto\x1a\"ydb/core/protos/kqp_physical.proto\x1a\x1fydb/core/protos/kqp_stats.proto\x1a!ydb/core/protos/query_stats.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\x1a%ydb/public/api/protos/ydb_table.proto\x1a%ydb/public/api/protos/ydb_value.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a%ydb/public/api/protos/ydb_topic.proto\x1a+ydb/library/mkql_proto/protos/minikql.proto\x1a\x30ydb/library/yql/dq/actors/protos/dq_events.proto\x1a/ydb/library/yql/dq/actors/protos/dq_stats.proto\x1a\'ydb/library/yql/dq/proto/dq_tasks.proto\"l\n\x10TTopicOperations\x12\x10\n\x08\x43onsumer\x18\x01 \x01(\t\x12\x46\n\x06Topics\x18\x02 \x03(\x0b\x32\x36.Ydb.Topic.AddOffsetsToTransactionRequest.TopicOffsets\"\x8e\x06\n\rTQueryRequest\x12\x11\n\tSessionId\x18\x01 \x01(\x0c\x12\r\n\x05Query\x18\x02 \x01(\t\x12$\n\x04Type\x18\x03 \x01(\x0e\x32\x16.NKikimrKqp.EQueryType\x12\x13\n\x0bKeepSession\x18\x05 \x01(\x08\x12+\n\nParameters\x18\x07 \x01(\x0b\x32\x17.NKikimrMiniKQL.TParams\x12(\n\x06\x41\x63tion\x18\t \x01(\x0e\x32\x18.NKikimrKqp.EQueryAction\x12\x15\n\rPreparedQuery\x18\x0b \x01(\x0c\x12\x15\n\nReplyFlags\x18\x0c \x01(\r:\x01\x31\x12\x30\n\tTxControl\x18\r \x01(\x0b\x32\x1d.Ydb.Table.TransactionControl\x12\x10\n\x08\x44\x61tabase\x18\x0e \x01(\t\x12\x35\n\x10QueryCachePolicy\x18\x0f \x01(\x0b\x32\x1b.Ydb.Table.QueryCachePolicy\x12\x15\n\rCancelAfterMs\x18\x10 \x01(\x04\x12\x11\n\tTimeoutMs\x18\x11 \x01(\x04\x12.\n\tStatsMode\x18\x14 \x01(\x0e\x32\x1b.NYql.NDqProto.EDqStatsMode\x12:\n\x0c\x43ollectStats\x18\x15 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\x12\x35\n\x0fTopicOperations\x18\x16 \x01(\x0b\x32\x1c.NKikimrKqp.TTopicOperations\x12#\n\x1bUsePublicResponseDataFormat\x18\x17 \x01(\x08\x12\x43\n\rYdbParameters\x18\x18 \x03(\x0b\x32,.NKikimrKqp.TQueryRequest.YdbParametersEntry\x1a\x45\n\x12YdbParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01J\x04\x08\x04\x10\x05J\x04\x08\x06\x10\x07J\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0bJ\x04\x08\x12\x10\x13J\x04\x08\x13\x10\x14\"3\n\x0fTKqpPathIdProto\x12\x0f\n\x07OwnerId\x18\x01 \x01(\r\x12\x0f\n\x07TableId\x18\x02 \x01(\r\"\xad\x01\n\x16TIndexDescriptionProto\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0c\n\x04Type\x18\x02 \x01(\r\x12\r\n\x05State\x18\x03 \x01(\r\x12\x15\n\rSchemaVersion\x18\x04 \x01(\r\x12\x13\n\x0bLocalPathId\x18\x05 \x01(\r\x12\x13\n\x0bPathOwnerId\x18\x06 \x01(\r\x12\x12\n\nKeyColumns\x18\x07 \x03(\t\x12\x13\n\x0b\x44\x61taColumns\x18\x08 \x03(\t\"\xa4\x01\n\x17TKqpColumnMetadataProto\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\n\n\x02Id\x18\x02 \x01(\r\x12\x0c\n\x04Type\x18\x03 \x01(\t\x12\x0e\n\x06TypeId\x18\x04 \x01(\r\x12)\n\x08TypeInfo\x18\x07 \x01(\x0b\x32\x17.NKikimrProto.TTypeInfo\x12\x0e\n\x06\x46\x61mily\x18\x05 \x03(\t\x12\x16\n\x07NotNull\x18\x06 \x01(\x08:\x05\x66\x61lse\"\xf1\x03\n\x16TKqpTableMetadataProto\x12\x11\n\tDoesExist\x18\x01 \x01(\x08\x12\x0f\n\x07\x43luster\x18\x02 \x01(\t\x12\x0c\n\x04Name\x18\x03 \x01(\t\x12\x0f\n\x07SysView\x18\x04 \x01(\t\x12+\n\x06PathId\x18\x05 \x01(\x0b\x32\x1b.NKikimrKqp.TKqpPathIdProto\x12\x15\n\rSchemaVersion\x18\x06 \x01(\r\x12\x0c\n\x04Kind\x18\x07 \x01(\r\x12\x46\n\nAttributes\x18\x08 \x03(\x0b\x32\x32.NKikimrKqp.TKqpTableMetadataProto.TAttributeProto\x12\x34\n\x07\x43olumns\x18\t \x03(\x0b\x32#.NKikimrKqp.TKqpColumnMetadataProto\x12\x16\n\x0eKeyColunmNames\x18\n \x03(\t\x12\x33\n\x07Indexes\x18\x0b \x03(\x0b\x32\".NKikimrKqp.TIndexDescriptionProto\x12H\n\x1cSecondaryGlobalIndexMetadata\x18\x0c \x03(\x0b\x32\".NKikimrKqp.TKqpTableMetadataProto\x1a-\n\x0fTAttributeProto\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\t\"9\n\x07TRlPath\x12\x18\n\x10\x43oordinationNode\x18\x01 \x01(\t\x12\x14\n\x0cResourcePath\x18\x02 \x01(\t\"\xd9\x02\n\x0fTEvQueryRequest\x12*\n\x07Request\x18\x01 \x01(\x0b\x32\x19.NKikimrKqp.TQueryRequest\x12\x0f\n\x07TraceId\x18\x02 \x01(\t\x12\x11\n\tUserToken\x18\x03 \x01(\t\x12.\n\x0eRequestActorId\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x13\n\x0bRequestType\x18\x05 \x01(\t\x12#\n\x06RlPath\x18\x06 \x01(\x0b\x32\x13.NKikimrKqp.TRlPath\x12,\n\x0bQueryIssues\x18\x07 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12,\n\tYdbStatus\x18\x08 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\x30\n\x10\x43\x61ncelationActor\x18\t \x01(\x0b\x32\x16.NActorsProto.TActorId\"K\n\x0cTMkqlProfile\x12\r\n\x05Query\x18\x01 \x01(\t\x12,\n\x07TxStats\x18\x02 \x01(\x0b\x32\x1b.NKikimrQueryStats.TTxStats\"\xd4\x01\n\x11TTransformProfile\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x1b\n\x13TransformDurationUs\x18\x02 \x01(\x04\x12\x16\n\x0eWaitDurationUs\x18\x03 \x01(\x04\x12\x14\n\x0cNewExprNodes\x18\x04 \x01(\x05\x12\x14\n\x0cNewTypeNodes\x18\x05 \x01(\x05\x12\x0f\n\x07Repeats\x18\x06 \x01(\r\x12\x10\n\x08Restarts\x18\x07 \x01(\r\x12-\n\x06Stages\x18\x64 \x03(\x0b\x32\x1d.NKikimrKqp.TTransformProfile\"\xc1\x01\n\x0bTKqlProfile\x12\r\n\x05Query\x18\x01 \x01(\t\x12.\n\x0cMkqlProfiles\x18\x02 \x03(\x0b\x32\x18.NKikimrKqp.TMkqlProfile\x12<\n\x17\x45\x66\x66\x65\x63tiveIsolationLevel\x18\x03 \x01(\x0e\x32\x1b.NKikimrKqp.EIsolationLevel\x12\x35\n\x0eTransformStats\x18\x04 \x01(\x0b\x32\x1d.NKikimrKqp.TTransformProfile\"t\n\rTQueryProfile\x12,\n\x0bKqlProfiles\x18\x01 \x03(\x0b\x32\x17.NKikimrKqp.TKqlProfile\x12\x35\n\x0eTransformStats\x18\x02 \x01(\x0b\x32\x1d.NKikimrKqp.TTransformProfile\"I\n\x11TParameterBinding\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x11\n\tMkqlIndex\x18\x02 \x01(\r\x12\x13\n\x0bResultIndex\x18\x03 \x01(\r\"`\n\x0fTPreparedResult\x12\x10\n\x08KqlIndex\x18\x01 \x01(\r\x12\x13\n\x0bResultIndex\x18\x02 \x01(\r\x12\x13\n\x0b\x43olumnHints\x18\x03 \x03(\t\x12\x11\n\tRowsLimit\x18\x04 \x01(\x04\"J\n\x15TParameterDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12#\n\x04Type\x18\x02 \x01(\x0b\x32\x15.NKikimrMiniKQL.TType\"\xa3\x02\n\x0eTPreparedQuery\x12\x0f\n\x07Version\x18\x01 \x01(\r\x12,\n\x07Results\x18\x03 \x03(\x0b\x32\x1b.NKikimrKqp.TPreparedResult\x12\x35\n\nParameters\x18\x04 \x03(\x0b\x32!.NKikimrKqp.TParameterDescription\x12\x0c\n\x04Text\x18\x05 \x01(\t\x12.\n\rPhysicalQuery\x18\x06 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyQuery\"W\n\x08\x45Version\x12\x17\n\x13VERSION_UNSPECIFIED\x10\x00\x12\x19\n\x15VERSION_V1_DEPRECATED\x10\x01\x12\x17\n\x13VERSION_PHYSICAL_V1\x10\x0bJ\x04\x08\x02\x10\x03\"\x84\x03\n\x0eTQueryResponse\x12\x11\n\tSessionId\x18\x01 \x01(\x0c\x12(\n\x07Results\x18\x03 \x03(\x0b\x32\x17.NKikimrMiniKQL.TResult\x12\x15\n\rPreparedQuery\x18\x05 \x01(\x0c\x12\x10\n\x08QueryAst\x18\x06 \x01(\t\x12,\n\x0bQueryIssues\x18\x08 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x11\n\tQueryPlan\x18\t \x01(\x0c\x12:\n\x0fQueryParameters\x18\n \x03(\x0b\x32!.NKikimrKqp.TParameterDescription\x12*\n\x06TxMeta\x18\x0b \x01(\x0b\x32\x1a.Ydb.Table.TransactionMeta\x12-\n\nQueryStats\x18\x0c \x01(\x0b\x32\x19.NKqpProto.TKqpStatsQuery\x12\"\n\nYdbResults\x18\r \x03(\x0b\x32\x0e.Ydb.ResultSetJ\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08\"\xb4\x01\n\x10TEvQueryResponse\x12,\n\x08Response\x18\x03 \x01(\x0b\x32\x1a.NKikimrKqp.TQueryResponse\x12,\n\tYdbStatus\x18\x04 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\x12\n\nConsumedRu\x18\x06 \x01(\x04\x12\x1e\n\x0fWorkerIsClosing\x18\x07 \x01(\x08:\x05\x66\x61lseJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06\")\n\x14TCloseSessionRequest\x12\x11\n\tSessionId\x18\x01 \x01(\x0c\"\\\n\x16TEvCloseSessionRequest\x12\x31\n\x07Request\x18\x01 \x01(\x0b\x32 .NKikimrKqp.TCloseSessionRequest\x12\x0f\n\x07TraceId\x18\x02 \x01(\t\":\n\x15TCloseSessionResponse\x12\x11\n\tSessionId\x18\x01 \x01(\x0c\x12\x0e\n\x06\x43losed\x18\x02 \x01(\x08\"\xa2\x01\n\x17TEvCloseSessionResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x33\n\x08Response\x18\x03 \x01(\x0b\x32!.NKikimrKqp.TCloseSessionResponse\"w\n\x12TEvProcessResponse\x12\r\n\x05\x45rror\x18\x02 \x01(\x0c\x12,\n\tYdbStatus\x18\x03 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\x1e\n\x0fWorkerIsClosing\x18\x04 \x01(\x08:\x05\x66\x61lseJ\x04\x08\x01\x10\x02\"*\n\x0bTKqpSetting\x12\x0c\n\x04Name\x18\x01 \x02(\t\x12\r\n\x05Value\x18\x02 \x02(\t\"G\n\x13TKqpDefaultSettings\x12\x30\n\x0f\x44\x65\x66\x61ultSettings\x18\x01 \x03(\x0b\x32\x17.NKikimrKqp.TKqpSetting\")\n\x15TCreateSessionRequest\x12\x10\n\x08\x44\x61tabase\x18\x01 \x01(\t\"\xbb\x01\n\x17TEvCreateSessionRequest\x12\x32\n\x07Request\x18\x01 \x01(\x0b\x32!.NKikimrKqp.TCreateSessionRequest\x12\x0f\n\x07TraceId\x18\x02 \x01(\t\x12\x12\n\nDeadlineUs\x18\x03 \x01(\x04\x12%\n\x16\x43\x61nCreateRemoteSession\x18\x04 \x01(\x08:\x05\x66\x61lse\x12 \n\x11SupportsBalancing\x18\x05 \x01(\x08:\x05\x66\x61lse\"+\n\x16TCreateSessionResponse\x12\x11\n\tSessionId\x18\x01 \x01(\x0c\"\xb5\x01\n\x18TEvCreateSessionResponse\x12\r\n\x05\x45rror\x18\x02 \x01(\x0c\x12\x34\n\x08Response\x18\x03 \x01(\x0b\x32\".NKikimrKqp.TCreateSessionResponse\x12,\n\tYdbStatus\x18\x04 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12 \n\x11ResourceExhausted\x18\x05 \x01(\x08:\x05\x66\x61lseJ\x04\x08\x01\x10\x02\"A\n\x13TPingSessionRequest\x12\x11\n\tSessionId\x18\x01 \x01(\x0c\x12\x17\n\tTimeoutMs\x18\x02 \x01(\r:\x04\x35\x30\x30\x30\"Z\n\x15TEvPingSessionRequest\x12\x30\n\x07Request\x18\x01 \x01(\x0b\x32\x1f.NKikimrKqp.TPingSessionRequest\x12\x0f\n\x07TraceId\x18\x02 \x01(\t\"w\n\x14TPingSessionResponse\x12?\n\rSessionStatus\x18\x01 \x01(\x0e\x32(.Ydb.Table.KeepAliveResult.SessionStatus\x12\x1e\n\x0fWorkerIsClosing\x18\x02 \x01(\x08:\x05\x66\x61lse\"\xc0\x01\n\x16TEvPingSessionResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x32\n\x08Response\x18\x03 \x01(\x0b\x32 .NKikimrKqp.TPingSessionResponse\x12\x1e\n\x0fWorkerIsClosing\x18\x04 \x01(\x08:\x05\x66\x61lse\"r\n\x16TEvDataQueryStreamPart\x12.\n\x0eGatewayActorId\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12(\n\x07Results\x18\x02 \x03(\x0b\x32\x17.NKikimrMiniKQL.TResult\"\"\n\x12TExecuterTxRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"\x93\x01\n\x14TEvExecuterTxRequest\x12/\n\x07Request\x18\x01 \x01(\x0b\x32\x1e.NKikimrKqp.TExecuterTxRequest\x12&\n\x06Target\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0f\n\x07TraceId\x18\x03 \x01(\t\x12\x11\n\tUserToken\x18\x04 \x01(\t\"~\n\x11TExecuterTxResult\x12&\n\x05Locks\x18\x04 \x01(\x0b\x32\x17.NKikimrMiniKQL.TResult\x12/\n\x05Stats\x18\x06 \x01(\x0b\x32 .NYql.NDqProto.TDqExecutionStatsJ\x04\x08\x03\x10\x04J\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08\"\x98\x01\n\x13TExecuterTxResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12-\n\x06Result\x18\x03 \x01(\x0b\x32\x1d.NKikimrKqp.TExecuterTxResult\"J\n\x15TEvExecuterTxResponse\x12\x31\n\x08Response\x18\x01 \x01(\x0b\x32\x1f.NKikimrKqp.TExecuterTxResponse\"I\n\x15TEvExecuterStreamData\x12!\n\tResultSet\x18\x01 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\"S\n\x18TEvExecuterStreamDataAck\x12\r\n\x05SeqNo\x18\x01 \x01(\x04\x12\x11\n\tFreeSpace\x18\x02 \x01(\x03\x12\x15\n\x06\x45nough\x18\x03 \x01(\x08:\x05\x66\x61lse\"S\n\x18TEvExecuterStreamProfile\x12\x31\n\x07Profile\x18\x02 \x01(\x0b\x32 .NYql.NDqProto.TDqExecutionStatsJ\x04\x08\x01\x10\x02\"F\n\x13TEvExecuterProgress\x12/\n\x0f\x45xecuterActorId\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\"\x96\x01\n\x16TKqpProxyNodeResources\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x17\n\x0f\x44\x61taCenterNumId\x18\x02 \x01(\x04\x12\x1a\n\x12\x41\x63tiveWorkersCount\x18\x03 \x01(\r\x12\x14\n\x0c\x44\x61taCenterId\x18\x04 \x01(\t\x12\x10\n\x08\x43puUsage\x18\x05 \x01(\x01\x12\x0f\n\x07Threads\x18\x06 \x01(\r\"*\n\x0cTKqpSnapshot\x12\x0c\n\x04Step\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\"\xef\x01\n\x14TEvStartComputeTasks\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12%\n\x05Tasks\x18\x02 \x03(\x0b\x32\x16.NYql.NDqProto.TDqTask\x12?\n\x0fRuntimeSettings\x18\x04 \x01(\x0b\x32&.NYql.NDqProto.TComputeRuntimeSettings\x12/\n\x0f\x45xecuterActorId\x18\x05 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12*\n\x08Snapshot\x18\x08 \x01(\x0b\x32\x18.NKikimrKqp.TKqpSnapshotJ\x04\x08\x03\x10\x04\"\xa8\x02\n\x1bTEvStartComputeTasksFailure\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12?\n\x06Reason\x18\x02 \x01(\x0e\x32/.NKikimrKqp.TEvStartComputeTasksFailure.EReason\x12\x0f\n\x07Message\x18\x03 \x01(\t\"\xa8\x01\n\x07\x45Reason\x12\x19\n\x15MEMORY_LIMIT_EXCEEDED\x10\x01\x12\x15\n\x11NOT_ENOUGH_MEMORY\x10\x02\x12!\n\x1d\x43OMPUTE_ACTORS_LIMIT_EXCEEDED\x10\x03\x12\x1d\n\x19NOT_ENOUGH_COMPUTE_ACTORS\x10\x04\x12\x1a\n\x16REQUEST_ALREADY_EXISTS\x10\x05\x12\r\n\tNOT_READY\x10\x06\"\xb6\x01\n\x16TEvStartedComputeTasks\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x45\n\x0cStartedTasks\x18\x02 \x03(\x0b\x32/.NKikimrKqp.TEvStartedComputeTasks.TStartedTask\x1aG\n\x0cTStartedTask\x12\x0e\n\x06TaskId\x18\x01 \x01(\x04\x12\'\n\x07\x41\x63torId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\"N\n\x15TEvCancelComputeTasks\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"\x8a\x02\n\x17TEvStartKqpTasksRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12%\n\x05Tasks\x18\x02 \x03(\x0b\x32\x16.NYql.NDqProto.TDqTask\x12?\n\x0fRuntimeSettings\x18\x03 \x01(\x0b\x32&.NYql.NDqProto.TComputeRuntimeSettings\x12/\n\x0f\x45xecuterActorId\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12*\n\x08Snapshot\x18\x05 \x01(\x0b\x32\x18.NKikimrKqp.TKqpSnapshot\x12\x1c\n\x0eStartAllOrFail\x18\x06 \x01(\x08:\x04true\"\xb9\x04\n\x18TEvStartKqpTasksResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12G\n\x0cStartedTasks\x18\x02 \x03(\x0b\x32\x31.NKikimrKqp.TEvStartKqpTasksResponse.TStartedTask\x12M\n\x0fNotStartedTasks\x18\x03 \x03(\x0b\x32\x34.NKikimrKqp.TEvStartKqpTasksResponse.TNotStartedTask\x1aG\n\x0cTStartedTask\x12\x0e\n\x06TaskId\x18\x01 \x01(\x04\x12\'\n\x07\x41\x63torId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x1a~\n\x0fTNotStartedTask\x12\x0e\n\x06TaskId\x18\x01 \x01(\x04\x12J\n\x06Reason\x18\x02 \x01(\x0e\x32:.NKikimrKqp.TEvStartKqpTasksResponse.ENotStartedTaskReason\x12\x0f\n\x07Message\x18\x03 \x01(\t\"\xad\x01\n\x15\x45NotStartedTaskReason\x12\x15\n\x11NOT_ENOUGH_MEMORY\x10\x01\x12\x1e\n\x1aNOT_ENOUGH_EXECUTION_UNITS\x10\x02\x12\x1f\n\x1bQUERY_MEMORY_LIMIT_EXCEEDED\x10\x03\x12(\n$QUERY_EXECUTION_UNITS_LIMIT_EXCEEDED\x10\x04\x12\x12\n\x0eINTERNAL_ERROR\x10\x05\"8\n\x18TEvCancelKqpTasksRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0e\n\x06Reason\x18\x02 \x01(\t\"\x1b\n\x19TEvCancelKqpTasksResponse\"\xd1\x03\n\x11TKqpNodeResources\x12\x36\n\x16ResourceManagerActorId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x1e\n\x16\x41vailableComputeActors\x18\x04 \x01(\r\x12\x12\n\nUsedMemory\x18\x05 \x01(\x04\x12\x13\n\x0bTotalMemory\x18\x07 \x01(\x04\x12@\n\x0cTransactions\x18\x06 \x03(\x0b\x32*.NKikimrKqp.TKqpNodeResources.TTxResources\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x11\n\tTimestamp\x18\x03 \x01(\r\x12\x35\n\x06Memory\x18\x08 \x03(\x0b\x32%.NKikimrKqp.TKqpNodeResources.TMemory\x12\x16\n\x0e\x45xecutionUnits\x18\t \x01(\r\x1a[\n\x0cTTxResources\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x15\n\rComputeActors\x18\x02 \x01(\r\x12\x0e\n\x06Memory\x18\x03 \x01(\x04\x12\x16\n\x0eStartTimestamp\x18\x04 \x01(\r\x1a*\n\x07TMemory\x12\x0c\n\x04Pool\x18\x01 \x01(\r\x12\x11\n\tAvailable\x18\x02 \x01(\x04\"c\n\x10TEvScanInitActor\x12\x0e\n\x06ScanId\x18\x01 \x01(\x04\x12+\n\x0bScanActorId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x12\n\nGeneration\x18\x03 \x01(\r\"v\n\x0cTEvScanError\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x12\n\nGeneration\x18\x03 \x01(\r\"\xa3\x02\n\x11TEvRemoteScanData\x12\x0e\n\x06ScanId\x18\x01 \x01(\r\x12\x11\n\tCpuTimeUs\x18\x02 \x01(\x04\x12\x12\n\nWaitTimeMs\x18\x03 \x01(\x04\x12\x12\n\nPageFaults\x18\x04 \x01(\r\x12\x11\n\tPageFault\x18\x05 \x01(\x08\x12\x10\n\x08\x46inished\x18\x06 \x01(\x08\x12\x0f\n\x07LastKey\x18\x07 \x01(\x0c\x12\x12\n\nGeneration\x18\t \x01(\r\x12\x0c\n\x04Rows\x18\x08 \x03(\x0c\x12=\n\nArrowBatch\x18\n \x01(\x0b\x32).NKikimrKqp.TEvRemoteScanData.TArrowBatch\x1a,\n\x0bTArrowBatch\x12\x0e\n\x06Schema\x18\x01 \x01(\x0c\x12\r\n\x05\x42\x61tch\x18\x02 \x01(\x0c\"=\n\x14TEvRemoteScanDataAck\x12\x11\n\tFreeSpace\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\r\"\xc2\x02\n\x11TEvRemoteCostData\x12\x0e\n\x06ScanId\x18\x01 \x01(\r\x12\x39\n\x08\x43ostInfo\x18\x02 \x01(\x0b\x32\'.NKikimrKqp.TEvRemoteCostData.TCostInfo\x1aK\n\rTIntervalMeta\x12\x1e\n\x0fIntervalSkipped\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x1a\n\x0cMarkIncluded\x18\x02 \x01(\x08:\x04true\x1a\x94\x01\n\tTCostInfo\x12\x41\n\x0cIntervalMeta\x18\x01 \x03(\x0b\x32+.NKikimrKqp.TEvRemoteCostData.TIntervalMeta\x12\x18\n\x10LeftBorderOpened\x18\x02 \x01(\x08\x12\x13\n\x0b\x43olumnsData\x18\x03 \x01(\x0c\x12\x15\n\rColumnsSchema\x18\x04 \x01(\x0c\"\x13\n\x11TEvKillScanTablet\"\xba\x01\n\x18TKqpStreamLookupSettings\x12&\n\x05Table\x18\x01 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyTable\x12\x12\n\nKeyColumns\x18\x02 \x03(\t\x12\x0f\n\x07\x43olumns\x18\x03 \x03(\t\x12*\n\x08Snapshot\x18\x04 \x01(\x0b\x32\x18.NKikimrKqp.TKqpSnapshot\x12\x10\n\x08LockTxId\x18\x05 \x01(\x04\x12\x13\n\x0bImmediateTx\x18\x06 \x01(\x08*o\n\x0c\x45RequestType\x12\x1e\n\x1aREQUEST_TYPE_PROCESS_QUERY\x10\x01\x12\x1e\n\x1aREQUEST_TYPE_CLOSE_SESSION\x10\x02\x12\x1f\n\x1bREQUEST_TYPE_CREATE_SESSION\x10\x03*\xa9\x02\n\nEQueryType\x12\x18\n\x14QUERY_TYPE_UNDEFINED\x10\x00\x12\x16\n\x12QUERY_TYPE_SQL_DML\x10\x04\x12\x16\n\x12QUERY_TYPE_SQL_DDL\x10\x05\x12\x1b\n\x17QUERY_TYPE_PREPARED_DML\x10\x06\x12\x16\n\x12QUERY_TYPE_AST_DML\x10\x07\x12\x19\n\x15QUERY_TYPE_SQL_SCRIPT\x10\x08\x12\x17\n\x13QUERY_TYPE_SQL_SCAN\x10\t\x12\x17\n\x13QUERY_TYPE_AST_SCAN\x10\n\x12#\n\x1fQUERY_TYPE_SQL_SCRIPT_STREAMING\x10\x0b\x12\x18\n\x14QUERY_TYPE_SQL_QUERY\x10\x0c\"\x04\x08\x01\x10\x01\"\x04\x08\x02\x10\x02\"\x04\x08\x03\x10\x03*\x9f\x02\n\x0c\x45QueryAction\x12\x18\n\x14QUERY_ACTION_EXECUTE\x10\x01\x12\x18\n\x14QUERY_ACTION_EXPLAIN\x10\x02\x12\x19\n\x15QUERY_ACTION_VALIDATE\x10\x03\x12\x18\n\x14QUERY_ACTION_PREPARE\x10\x04\x12!\n\x1dQUERY_ACTION_EXECUTE_PREPARED\x10\x05\x12\x19\n\x15QUERY_ACTION_BEGIN_TX\x10\x06\x12\x1a\n\x16QUERY_ACTION_COMMIT_TX\x10\x07\x12\x1c\n\x18QUERY_ACTION_ROLLBACK_TX\x10\x08\x12\x16\n\x12QUERY_ACTION_PARSE\x10\t\x12\x16\n\x12QUERY_ACTION_TOPIC\x10\n*\xbc\x01\n\x0f\x45IsolationLevel\x12\x1d\n\x19ISOLATION_LEVEL_UNDEFINED\x10\x00\x12 \n\x1cISOLATION_LEVEL_SERIALIZABLE\x10\x01\x12\"\n\x1eISOLATION_LEVEL_READ_COMMITTED\x10\x02\x12$\n ISOLATION_LEVEL_READ_UNCOMMITTED\x10\x03\x12\x1e\n\x1aISOLATION_LEVEL_READ_STALE\x10\x04*e\n\x10\x45QueryReplyFlags\x12\x1c\n\x18QUERY_REPLY_FLAG_RESULTS\x10\x01\x12\x19\n\x15QUERY_REPLY_FLAG_PLAN\x10\x02\x12\x18\n\x14QUERY_REPLY_FLAG_AST\x10\x04\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.kqp_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TQUERYREQUEST_YDBPARAMETERSENTRY._options = None
  _TQUERYREQUEST_YDBPARAMETERSENTRY._serialized_options = b'8\001'
  _EREQUESTTYPE._serialized_start=10561
  _EREQUESTTYPE._serialized_end=10672
  _EQUERYTYPE._serialized_start=10675
  _EQUERYTYPE._serialized_end=10972
  _EQUERYACTION._serialized_start=10975
  _EQUERYACTION._serialized_end=11262
  _EISOLATIONLEVEL._serialized_start=11265
  _EISOLATIONLEVEL._serialized_end=11453
  _EQUERYREPLYFLAGS._serialized_start=11455
  _EQUERYREPLYFLAGS._serialized_end=11556
  _TTOPICOPERATIONS._serialized_start=613
  _TTOPICOPERATIONS._serialized_end=721
  _TQUERYREQUEST._serialized_start=724
  _TQUERYREQUEST._serialized_end=1506
  _TQUERYREQUEST_YDBPARAMETERSENTRY._serialized_start=1401
  _TQUERYREQUEST_YDBPARAMETERSENTRY._serialized_end=1470
  _TKQPPATHIDPROTO._serialized_start=1508
  _TKQPPATHIDPROTO._serialized_end=1559
  _TINDEXDESCRIPTIONPROTO._serialized_start=1562
  _TINDEXDESCRIPTIONPROTO._serialized_end=1735
  _TKQPCOLUMNMETADATAPROTO._serialized_start=1738
  _TKQPCOLUMNMETADATAPROTO._serialized_end=1902
  _TKQPTABLEMETADATAPROTO._serialized_start=1905
  _TKQPTABLEMETADATAPROTO._serialized_end=2402
  _TKQPTABLEMETADATAPROTO_TATTRIBUTEPROTO._serialized_start=2357
  _TKQPTABLEMETADATAPROTO_TATTRIBUTEPROTO._serialized_end=2402
  _TRLPATH._serialized_start=2404
  _TRLPATH._serialized_end=2461
  _TEVQUERYREQUEST._serialized_start=2464
  _TEVQUERYREQUEST._serialized_end=2809
  _TMKQLPROFILE._serialized_start=2811
  _TMKQLPROFILE._serialized_end=2886
  _TTRANSFORMPROFILE._serialized_start=2889
  _TTRANSFORMPROFILE._serialized_end=3101
  _TKQLPROFILE._serialized_start=3104
  _TKQLPROFILE._serialized_end=3297
  _TQUERYPROFILE._serialized_start=3299
  _TQUERYPROFILE._serialized_end=3415
  _TPARAMETERBINDING._serialized_start=3417
  _TPARAMETERBINDING._serialized_end=3490
  _TPREPAREDRESULT._serialized_start=3492
  _TPREPAREDRESULT._serialized_end=3588
  _TPARAMETERDESCRIPTION._serialized_start=3590
  _TPARAMETERDESCRIPTION._serialized_end=3664
  _TPREPAREDQUERY._serialized_start=3667
  _TPREPAREDQUERY._serialized_end=3958
  _TPREPAREDQUERY_EVERSION._serialized_start=3865
  _TPREPAREDQUERY_EVERSION._serialized_end=3952
  _TQUERYRESPONSE._serialized_start=3961
  _TQUERYRESPONSE._serialized_end=4349
  _TEVQUERYRESPONSE._serialized_start=4352
  _TEVQUERYRESPONSE._serialized_end=4532
  _TCLOSESESSIONREQUEST._serialized_start=4534
  _TCLOSESESSIONREQUEST._serialized_end=4575
  _TEVCLOSESESSIONREQUEST._serialized_start=4577
  _TEVCLOSESESSIONREQUEST._serialized_end=4669
  _TCLOSESESSIONRESPONSE._serialized_start=4671
  _TCLOSESESSIONRESPONSE._serialized_end=4729
  _TEVCLOSESESSIONRESPONSE._serialized_start=4732
  _TEVCLOSESESSIONRESPONSE._serialized_end=4894
  _TEVPROCESSRESPONSE._serialized_start=4896
  _TEVPROCESSRESPONSE._serialized_end=5015
  _TKQPSETTING._serialized_start=5017
  _TKQPSETTING._serialized_end=5059
  _TKQPDEFAULTSETTINGS._serialized_start=5061
  _TKQPDEFAULTSETTINGS._serialized_end=5132
  _TCREATESESSIONREQUEST._serialized_start=5134
  _TCREATESESSIONREQUEST._serialized_end=5175
  _TEVCREATESESSIONREQUEST._serialized_start=5178
  _TEVCREATESESSIONREQUEST._serialized_end=5365
  _TCREATESESSIONRESPONSE._serialized_start=5367
  _TCREATESESSIONRESPONSE._serialized_end=5410
  _TEVCREATESESSIONRESPONSE._serialized_start=5413
  _TEVCREATESESSIONRESPONSE._serialized_end=5594
  _TPINGSESSIONREQUEST._serialized_start=5596
  _TPINGSESSIONREQUEST._serialized_end=5661
  _TEVPINGSESSIONREQUEST._serialized_start=5663
  _TEVPINGSESSIONREQUEST._serialized_end=5753
  _TPINGSESSIONRESPONSE._serialized_start=5755
  _TPINGSESSIONRESPONSE._serialized_end=5874
  _TEVPINGSESSIONRESPONSE._serialized_start=5877
  _TEVPINGSESSIONRESPONSE._serialized_end=6069
  _TEVDATAQUERYSTREAMPART._serialized_start=6071
  _TEVDATAQUERYSTREAMPART._serialized_end=6185
  _TEXECUTERTXREQUEST._serialized_start=6187
  _TEXECUTERTXREQUEST._serialized_end=6221
  _TEVEXECUTERTXREQUEST._serialized_start=6224
  _TEVEXECUTERTXREQUEST._serialized_end=6371
  _TEXECUTERTXRESULT._serialized_start=6373
  _TEXECUTERTXRESULT._serialized_end=6499
  _TEXECUTERTXRESPONSE._serialized_start=6502
  _TEXECUTERTXRESPONSE._serialized_end=6654
  _TEVEXECUTERTXRESPONSE._serialized_start=6656
  _TEVEXECUTERTXRESPONSE._serialized_end=6730
  _TEVEXECUTERSTREAMDATA._serialized_start=6732
  _TEVEXECUTERSTREAMDATA._serialized_end=6805
  _TEVEXECUTERSTREAMDATAACK._serialized_start=6807
  _TEVEXECUTERSTREAMDATAACK._serialized_end=6890
  _TEVEXECUTERSTREAMPROFILE._serialized_start=6892
  _TEVEXECUTERSTREAMPROFILE._serialized_end=6975
  _TEVEXECUTERPROGRESS._serialized_start=6977
  _TEVEXECUTERPROGRESS._serialized_end=7047
  _TKQPPROXYNODERESOURCES._serialized_start=7050
  _TKQPPROXYNODERESOURCES._serialized_end=7200
  _TKQPSNAPSHOT._serialized_start=7202
  _TKQPSNAPSHOT._serialized_end=7244
  _TEVSTARTCOMPUTETASKS._serialized_start=7247
  _TEVSTARTCOMPUTETASKS._serialized_end=7486
  _TEVSTARTCOMPUTETASKSFAILURE._serialized_start=7489
  _TEVSTARTCOMPUTETASKSFAILURE._serialized_end=7785
  _TEVSTARTCOMPUTETASKSFAILURE_EREASON._serialized_start=7617
  _TEVSTARTCOMPUTETASKSFAILURE_EREASON._serialized_end=7785
  _TEVSTARTEDCOMPUTETASKS._serialized_start=7788
  _TEVSTARTEDCOMPUTETASKS._serialized_end=7970
  _TEVSTARTEDCOMPUTETASKS_TSTARTEDTASK._serialized_start=7899
  _TEVSTARTEDCOMPUTETASKS_TSTARTEDTASK._serialized_end=7970
  _TEVCANCELCOMPUTETASKS._serialized_start=7972
  _TEVCANCELCOMPUTETASKS._serialized_end=8050
  _TEVSTARTKQPTASKSREQUEST._serialized_start=8053
  _TEVSTARTKQPTASKSREQUEST._serialized_end=8319
  _TEVSTARTKQPTASKSRESPONSE._serialized_start=8322
  _TEVSTARTKQPTASKSRESPONSE._serialized_end=8891
  _TEVSTARTKQPTASKSRESPONSE_TSTARTEDTASK._serialized_start=7899
  _TEVSTARTKQPTASKSRESPONSE_TSTARTEDTASK._serialized_end=7970
  _TEVSTARTKQPTASKSRESPONSE_TNOTSTARTEDTASK._serialized_start=8589
  _TEVSTARTKQPTASKSRESPONSE_TNOTSTARTEDTASK._serialized_end=8715
  _TEVSTARTKQPTASKSRESPONSE_ENOTSTARTEDTASKREASON._serialized_start=8718
  _TEVSTARTKQPTASKSRESPONSE_ENOTSTARTEDTASKREASON._serialized_end=8891
  _TEVCANCELKQPTASKSREQUEST._serialized_start=8893
  _TEVCANCELKQPTASKSREQUEST._serialized_end=8949
  _TEVCANCELKQPTASKSRESPONSE._serialized_start=8951
  _TEVCANCELKQPTASKSRESPONSE._serialized_end=8978
  _TKQPNODERESOURCES._serialized_start=8981
  _TKQPNODERESOURCES._serialized_end=9446
  _TKQPNODERESOURCES_TTXRESOURCES._serialized_start=9311
  _TKQPNODERESOURCES_TTXRESOURCES._serialized_end=9402
  _TKQPNODERESOURCES_TMEMORY._serialized_start=9404
  _TKQPNODERESOURCES_TMEMORY._serialized_end=9446
  _TEVSCANINITACTOR._serialized_start=9448
  _TEVSCANINITACTOR._serialized_end=9547
  _TEVSCANERROR._serialized_start=9549
  _TEVSCANERROR._serialized_end=9667
  _TEVREMOTESCANDATA._serialized_start=9670
  _TEVREMOTESCANDATA._serialized_end=9961
  _TEVREMOTESCANDATA_TARROWBATCH._serialized_start=9917
  _TEVREMOTESCANDATA_TARROWBATCH._serialized_end=9961
  _TEVREMOTESCANDATAACK._serialized_start=9963
  _TEVREMOTESCANDATAACK._serialized_end=10024
  _TEVREMOTECOSTDATA._serialized_start=10027
  _TEVREMOTECOSTDATA._serialized_end=10349
  _TEVREMOTECOSTDATA_TINTERVALMETA._serialized_start=10123
  _TEVREMOTECOSTDATA_TINTERVALMETA._serialized_end=10198
  _TEVREMOTECOSTDATA_TCOSTINFO._serialized_start=10201
  _TEVREMOTECOSTDATA_TCOSTINFO._serialized_end=10349
  _TEVKILLSCANTABLET._serialized_start=10351
  _TEVKILLSCANTABLET._serialized_end=10370
  _TKQPSTREAMLOOKUPSETTINGS._serialized_start=10373
  _TKQPSTREAMLOOKUPSETTINGS._serialized_end=10559
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blob_depot_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ydb/core/protos/blob_depot_config.proto\x12\x10NKikimrBlobDepot\"2\n\x0cTChannelKind\"\"\n\x01\x45\x12\n\n\x06System\x10\x00\x12\x08\n\x04\x44\x61ta\x10\x01\x12\x07\n\x03Log\x10\x02\"\x89\x01\n\x0fTChannelProfile\x12\x17\n\x0fStoragePoolName\x18\x01 \x01(\t\x12\x17\n\x0fStoragePoolKind\x18\x02 \x01(\t\x12\r\n\x05\x43ount\x18\x03 \x01(\r\x12\x35\n\x0b\x43hannelKind\x18\x04 \x01(\x0e\x32 .NKikimrBlobDepot.TChannelKind.E\"\x83\x01\n\x10TBlobDepotConfig\x12:\n\x0f\x43hannelProfiles\x18\x01 \x03(\x0b\x32!.NKikimrBlobDepot.TChannelProfile\x12\x16\n\x0eVirtualGroupId\x18\x02 \x01(\r\x12\x1b\n\x13IsDecommittingGroup\x18\x03 \x01(\x08')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blob_depot_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TCHANNELKIND._serialized_start=61
  _TCHANNELKIND._serialized_end=111
  _TCHANNELKIND_E._serialized_start=77
  _TCHANNELKIND_E._serialized_end=111
  _TCHANNELPROFILE._serialized_start=114
  _TCHANNELPROFILE._serialized_end=251
  _TBLOBDEPOTCONFIG._serialized_start=254
  _TBLOBDEPOTCONFIG._serialized_end=385
# @@protoc_insertion_point(module_scope)



import ydb.apps.dstool.lib.common as common
import ydb.apps.dstool.lib.grouptool as grouptool
import sys

description = 'Wipe vdisks'


def add_options(p):
    common.add_vdisk_ids_option(p, required=True)
    p.add_argument('--force', action='store_true', help='Force execution in spite of group safety check results')
    common.add_ignore_degraded_group_check_option(p)
    common.add_ignore_disintegrated_group_check_option(p)
    common.add_ignore_failure_model_group_check_option(p)
    p.add_argument('--run', action='store_true', help='Run command (by default the command is not run)')
    common.add_basic_format_options(p)


def create_request(args, vslot):
    return common.create_wipe_request(args=args, vslot=vslot)


def perform_request(request):
    return common.invoke_wipe_request(request)


def is_successful_response(response):
    return common.is_successful_bsc_response(response)


def do(args):
    base_config_and_storage_pools = common.fetch_base_config_and_storage_pools()
    base_config = base_config_and_storage_pools['BaseConfig']

    node_fqdn_map = common.build_node_fqdn_map(base_config)
    storage_pools = base_config_and_storage_pools['StoragePools']
    storage_pools_map = common.build_storage_pools_map(storage_pools)

    vslot_status = {
        common.get_vslot_id(vslot.VSlotId): vslot.Status == 'READY'
        for vslot in base_config.VSlot
    }
    for vslot in base_config.VSlot:
        if not vslot.Status:
            vslot_id = common.get_vslot_id(vslot.VSlotId)
            node_fqdn = node_fqdn_map[vslot.VSlotId.NodeId]
            try:
                json_data = common.fetch('viewer/json/vdiskinfo', dict(node_id=0, enums=1), node_fqdn)
                vdisks = [
                    vslot_data
                    for vslot_data in json_data.get('VDiskStateInfo', [])
                    if tuple(map(vslot_data.__getitem__, ('NodeId', 'PDiskId', 'VDiskSlotId'))) == vslot_id
                ]
                if not vdisks:
                    raise Exception('No matching VDisks')
                elif len(vdisks) > 1:
                    raise Exception('Too many matching VDisks')
                vdisk = vdisks[0]
                vslot_status[vslot_id] = vdisk['VDiskState'] == 'OK' and vdisk['Replicated'] is True
            except Exception as e:
                common.print_if_not_quiet(args, 'Failed to query VDisk status for group %d host %s: %s' % (vslot.GroupId, node_fqdn, e), file=sys.stderr)

    vslot_coord = {
        common.get_vslot_id(vslot.VSlotId): (vslot.FailRealmIdx, vslot.FailDomainIdx, vslot.VDiskIdx)
        for vslot in base_config.VSlot
    }

    def get_vslots():
        vslot_map = {}
        for v in base_config.VSlot:
            vslot_map['[%08x:_:%d:%d:%d]' % (v.GroupId, v.FailRealmIdx, v.FailDomainIdx, v.VDiskIdx)] = v
            vslot_map['[%08x:%d:%d:%d:%d]' % (v.GroupId, v.GroupGeneration, v.FailRealmIdx, v.FailDomainIdx, v.VDiskIdx)] = v

        def find_vslot(vdisk_id):
            res = vslot_map.get(vdisk_id)
            if res is None:
                common.print_status(args, success=False, error_reason="Couldn't find VDisk with id %s" % vdisk_id)
                sys.exit(1)
            return res
        return (find_vslot(vdisk_id) for vdisk_id in args.vdisk_ids)

    wipe_set = {
        (vslot.GroupId,) + v: vslot
        for vslot in get_vslots()
        for v in [common.get_vslot_id(vslot.VSlotId)]
    }

    if not wipe_set:
        common.print_status(args, success=False, error_reason="Couldn't get any VDisks")
        sys.exit(1)

    def do_failure_model_group_checks():
        success = True
        for group in base_config.Group:
            group_vslots = set(map(common.get_vslot_id, group.VSlotId))
            wiped = group_vslots & set(v[1:] for v in wipe_set)
            if not wiped:
                continue  # ignore groups we are not going to wipe
            sp = storage_pools_map[group.BoxId, group.StoragePoolId]
            current = {
                vslot_coord[v]: vslot_status[v]
                for v in group_vslots
            }
            new = {
                vslot_coord[v]: vslot_status[v] and v not in wiped
                for v in group_vslots
            }
            current_status = grouptool.check_fail_model(current, sp.ErasureSpecies)
            new_status = grouptool.check_fail_model(new, sp.ErasureSpecies)
            if current_status and not new_status:
                success = False
                common.print_if_verbose(args, 'Group %d will lose its data during the operation' % group.GroupId, file=sys.stderr)
            elif not new_status:
                success = False
                common.print_if_verbose(args, 'Group %d will remain degraded after the operation' % group.GroupId, file=sys.stderr)
        return success

    if not do_failure_model_group_checks() and not args.force:
        common.print_status(args, success=False, error_reason='Check of groups failure model has failed')
        sys.exit(1)

    for item in sorted(wipe_set):
        common.print_if_verbose(args, 'About to wipe disk with GroupId# %d NodeId# %d PDiskId# %d VSlotId# %d' % item, file=sys.stderr)

    if args.run:
        success = True
        error_reason = ''
        for item in sorted(wipe_set):
            vslot = wipe_set[item]

            request = create_request(args, vslot)
            response = perform_request(request)
            if not is_successful_response(response):
                success = False
                error_reason += 'Request has failed: \n{0}\n{1}\n'.format(request, response)

        common.print_status(args, success, error_reason)
        if not success:
            sys.exit(1)
    else:
        common.print_result(args.format, 'error', 'For safety reasons the command is not run by default, use --run to run the command', file=sys.stderr)
        sys.exit(1)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tx_sequenceshard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ydb/core/protos/tx_sequenceshard.proto\x12\x16NKikimrTxSequenceShard\x1a\x1aydb/core/protos/base.proto\"R\n\x16TEvMarkSchemeShardPipe\x12\x15\n\rSchemeShardId\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\r\n\x05Round\x18\x03 \x01(\x04\"\xc4\x02\n\x11TEvCreateSequence\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TxPartId\x18\x03 \x01(\x04\x12\x12\n\x08MinValue\x18\x04 \x01(\x12H\x00\x12\x12\n\x08MaxValue\x18\x05 \x01(\x12H\x01\x12\x14\n\nStartValue\x18\x06 \x01(\x12H\x02\x12\x0f\n\x05\x43\x61\x63he\x18\x07 \x01(\x04H\x03\x12\x13\n\tIncrement\x18\x08 \x01(\x12H\x04\x12\x0f\n\x05\x43ycle\x18\t \x01(\x08H\x05\x42\x12\n\x10OptionalMinValueB\x12\n\x10OptionalMaxValueB\x14\n\x12OptionalStartValueB\x0f\n\rOptionalCacheB\x13\n\x11OptionalIncrementB\x0f\n\rOptionalCycle\"\xe7\x01\n\x17TEvCreateSequenceResult\x12G\n\x06Status\x18\x01 \x01(\x0e\x32\x37.NKikimrTxSequenceShard.TEvCreateSequenceResult.EStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x10\n\x08TxPartId\x18\x04 \x01(\x04\"S\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rPIPE_OUTDATED\x10\x02\x12\x1b\n\x17SEQUENCE_ALREADY_EXISTS\x10\x03\"K\n\x13TEvAllocateSequence\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\r\n\x05\x43\x61\x63he\x18\x02 \x01(\x04\"\xe7\x02\n\x19TEvAllocateSequenceResult\x12I\n\x06Status\x18\x01 \x01(\x0e\x32\x39.NKikimrTxSequenceShard.TEvAllocateSequenceResult.EStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x17\n\x0f\x41llocationStart\x18\x03 \x01(\x12\x12\x17\n\x0f\x41llocationCount\x18\x04 \x01(\x04\x12\x1b\n\x13\x41llocationIncrement\x18\x05 \x01(\x12\x12\x0f\n\x07MovedTo\x18\x06 \x01(\x04\"\x8e\x01\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rPIPE_OUTDATED\x10\x02\x12\x16\n\x12SEQUENCE_NOT_FOUND\x10\x03\x12\x13\n\x0fSEQUENCE_FROZEN\x10\x04\x12\x12\n\x0eSEQUENCE_MOVED\x10\x05\x12\x15\n\x11SEQUENCE_OVERFLOW\x10\x06\"X\n\x0fTEvDropSequence\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TxPartId\x18\x03 \x01(\x04\"\xde\x01\n\x15TEvDropSequenceResult\x12\x45\n\x06Status\x18\x01 \x01(\x0e\x32\x35.NKikimrTxSequenceShard.TEvDropSequenceResult.EStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x10\n\x08TxPartId\x18\x04 \x01(\x04\"N\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rPIPE_OUTDATED\x10\x02\x12\x16\n\x12SEQUENCE_NOT_FOUND\x10\x03\"\x86\x03\n\x11TEvUpdateSequence\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TxPartId\x18\x03 \x01(\x04\x12\x12\n\x08MinValue\x18\x04 \x01(\x12H\x00\x12\x12\n\x08MaxValue\x18\x05 \x01(\x12H\x01\x12\x14\n\nStartValue\x18\x06 \x01(\x12H\x02\x12\x13\n\tNextValue\x18\x07 \x01(\x12H\x03\x12\x12\n\x08NextUsed\x18\x08 \x01(\x08H\x04\x12\x0f\n\x05\x43\x61\x63he\x18\t \x01(\x04H\x05\x12\x13\n\tIncrement\x18\n \x01(\x12H\x06\x12\x0f\n\x05\x43ycle\x18\x0b \x01(\x08H\x07\x42\x10\n\x0e\x43hangeMinValueB\x10\n\x0e\x43hangeMaxValueB\x12\n\x10\x43hangeStartValueB\x11\n\x0f\x43hangeNextValueB\x10\n\x0e\x43hangeNextUsedB\r\n\x0b\x43hangeCacheB\x11\n\x0f\x43hangeIncrementB\r\n\x0b\x43hangeCycle\"\x9c\x02\n\x17TEvUpdateSequenceResult\x12G\n\x06Status\x18\x01 \x01(\x0e\x32\x37.NKikimrTxSequenceShard.TEvUpdateSequenceResult.EStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x10\n\x08TxPartId\x18\x04 \x01(\x04\x12\x0f\n\x07MovedTo\x18\x05 \x01(\x04\"w\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rPIPE_OUTDATED\x10\x02\x12\x16\n\x12SEQUENCE_NOT_FOUND\x10\x03\x12\x13\n\x0fSEQUENCE_FROZEN\x10\x04\x12\x12\n\x0eSEQUENCE_MOVED\x10\x05\"Z\n\x11TEvFreezeSequence\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TxPartId\x18\x03 \x01(\x04\"\x95\x03\n\x17TEvFreezeSequenceResult\x12G\n\x06Status\x18\x01 \x01(\x0e\x32\x37.NKikimrTxSequenceShard.TEvFreezeSequenceResult.EStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x10\n\x08TxPartId\x18\x04 \x01(\x04\x12\x0f\n\x07MovedTo\x18\x05 \x01(\x04\x12\x10\n\x08MinValue\x18\x06 \x01(\x12\x12\x10\n\x08MaxValue\x18\x07 \x01(\x12\x12\x12\n\nStartValue\x18\x08 \x01(\x12\x12\x11\n\tNextValue\x18\t \x01(\x12\x12\x10\n\x08NextUsed\x18\n \x01(\x08\x12\r\n\x05\x43\x61\x63he\x18\x0b \x01(\x04\x12\x11\n\tIncrement\x18\x0c \x01(\x12\x12\r\n\x05\x43ycle\x18\r \x01(\x08\"b\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rPIPE_OUTDATED\x10\x02\x12\x16\n\x12SEQUENCE_NOT_FOUND\x10\x03\x12\x12\n\x0eSEQUENCE_MOVED\x10\x04\"\xe9\x01\n\x12TEvRestoreSequence\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TxPartId\x18\x03 \x01(\x04\x12\x10\n\x08MinValue\x18\x04 \x01(\x12\x12\x10\n\x08MaxValue\x18\x05 \x01(\x12\x12\x12\n\nStartValue\x18\x06 \x01(\x12\x12\x11\n\tNextValue\x18\x07 \x01(\x12\x12\x10\n\x08NextUsed\x18\x08 \x01(\x08\x12\r\n\x05\x43\x61\x63he\x18\t \x01(\x04\x12\x11\n\tIncrement\x18\n \x01(\x12\x12\r\n\x05\x43ycle\x18\x0b \x01(\x08\"\xe9\x01\n\x18TEvRestoreSequenceResult\x12H\n\x06Status\x18\x01 \x01(\x0e\x32\x38.NKikimrTxSequenceShard.TEvRestoreSequenceResult.EStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x10\n\x08TxPartId\x18\x04 \x01(\x04\"S\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rPIPE_OUTDATED\x10\x02\x12\x1b\n\x17SEQUENCE_ALREADY_ACTIVE\x10\x03\"p\n\x13TEvRedirectSequence\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TxPartId\x18\x03 \x01(\x04\x12\x12\n\nRedirectTo\x18\x04 \x01(\x04\"\xe6\x01\n\x19TEvRedirectSequenceResult\x12I\n\x06Status\x18\x01 \x01(\x0e\x32\x39.NKikimrTxSequenceShard.TEvRedirectSequenceResult.EStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x10\n\x08TxPartId\x18\x04 \x01(\x04\"N\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rPIPE_OUTDATED\x10\x02\x12\x16\n\x12SEQUENCE_NOT_FOUND\x10\x03\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tx_sequenceshard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TEVMARKSCHEMESHARDPIPE._serialized_start=94
  _TEVMARKSCHEMESHARDPIPE._serialized_end=176
  _TEVCREATESEQUENCE._serialized_start=179
  _TEVCREATESEQUENCE._serialized_end=503
  _TEVCREATESEQUENCERESULT._serialized_start=506
  _TEVCREATESEQUENCERESULT._serialized_end=737
  _TEVCREATESEQUENCERESULT_ESTATUS._serialized_start=654
  _TEVCREATESEQUENCERESULT_ESTATUS._serialized_end=737
  _TEVALLOCATESEQUENCE._serialized_start=739
  _TEVALLOCATESEQUENCE._serialized_end=814
  _TEVALLOCATESEQUENCERESULT._serialized_start=817
  _TEVALLOCATESEQUENCERESULT._serialized_end=1176
  _TEVALLOCATESEQUENCERESULT_ESTATUS._serialized_start=1034
  _TEVALLOCATESEQUENCERESULT_ESTATUS._serialized_end=1176
  _TEVDROPSEQUENCE._serialized_start=1178
  _TEVDROPSEQUENCE._serialized_end=1266
  _TEVDROPSEQUENCERESULT._serialized_start=1269
  _TEVDROPSEQUENCERESULT._serialized_end=1491
  _TEVDROPSEQUENCERESULT_ESTATUS._serialized_start=1034
  _TEVDROPSEQUENCERESULT_ESTATUS._serialized_end=1112
  _TEVUPDATESEQUENCE._serialized_start=1494
  _TEVUPDATESEQUENCE._serialized_end=1884
  _TEVUPDATESEQUENCERESULT._serialized_start=1887
  _TEVUPDATESEQUENCERESULT._serialized_end=2171
  _TEVUPDATESEQUENCERESULT_ESTATUS._serialized_start=1034
  _TEVUPDATESEQUENCERESULT_ESTATUS._serialized_end=1153
  _TEVFREEZESEQUENCE._serialized_start=2173
  _TEVFREEZESEQUENCE._serialized_end=2263
  _TEVFREEZESEQUENCERESULT._serialized_start=2266
  _TEVFREEZESEQUENCERESULT._serialized_end=2671
  _TEVFREEZESEQUENCERESULT_ESTATUS._serialized_start=2573
  _TEVFREEZESEQUENCERESULT_ESTATUS._serialized_end=2671
  _TEVRESTORESEQUENCE._serialized_start=2674
  _TEVRESTORESEQUENCE._serialized_end=2907
  _TEVRESTORESEQUENCERESULT._serialized_start=2910
  _TEVRESTORESEQUENCERESULT._serialized_end=3143
  _TEVRESTORESEQUENCERESULT_ESTATUS._serialized_start=3060
  _TEVRESTORESEQUENCERESULT_ESTATUS._serialized_end=3143
  _TEVREDIRECTSEQUENCE._serialized_start=3145
  _TEVREDIRECTSEQUENCE._serialized_end=3257
  _TEVREDIRECTSEQUENCERESULT._serialized_start=3260
  _TEVREDIRECTSEQUENCERESULT._serialized_end=3490
  _TEVREDIRECTSEQUENCERESULT_ESTATUS._serialized_start=1034
  _TEVREDIRECTSEQUENCERESULT_ESTATUS._serialized_end=1112
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tablet_counters.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ydb/core/protos/tablet_counters.proto\x12\x11NKikimrTabletBase\"3\n\x14TTabletSimpleCounter\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\x04\"7\n\x18TTabletCumulativeCounter\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\x04\"H\n\x18TTabletPercentileCounter\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06Ranges\x18\x02 \x03(\t\x12\x0e\n\x06Values\x18\x03 \x03(\x04\"\xe8\x01\n\x13TTabletCountersBase\x12?\n\x0eSimpleCounters\x18\x01 \x03(\x0b\x32\'.NKikimrTabletBase.TTabletSimpleCounter\x12G\n\x12\x43umulativeCounters\x18\x02 \x03(\x0b\x32+.NKikimrTabletBase.TTabletCumulativeCounter\x12G\n\x12PercentileCounters\x18\x03 \x03(\x0b\x32+.NKikimrTabletBase.TTabletPercentileCounter\"\x90\x01\n\x0fTTabletCounters\x12@\n\x10\x45xecutorCounters\x18\x01 \x01(\x0b\x32&.NKikimrTabletBase.TTabletCountersBase\x12;\n\x0b\x41ppCounters\x18\x02 \x01(\x0b\x32&.NKikimrTabletBase.TTabletCountersBaseB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tablet_counters_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TTABLETSIMPLECOUNTER._serialized_start=60
  _TTABLETSIMPLECOUNTER._serialized_end=111
  _TTABLETCUMULATIVECOUNTER._serialized_start=113
  _TTABLETCUMULATIVECOUNTER._serialized_end=168
  _TTABLETPERCENTILECOUNTER._serialized_start=170
  _TTABLETPERCENTILECOUNTER._serialized_end=242
  _TTABLETCOUNTERSBASE._serialized_start=245
  _TTABLETCOUNTERSBASE._serialized_end=477
  _TTABLETCOUNTERS._serialized_start=480
  _TTABLETCOUNTERS._serialized_end=624
# @@protoc_insertion_point(module_scope)
